@@ -17,25 +17,29 @@
 """ Class for custom products """
 import logging
 from datetime import datetime
+from enum import unique
 from pathlib import Path
 from typing import Union
 
 import geopandas as gpd
 import numpy as np
 import rasterio
+import xarray as xr
 from cloudpathlib import CloudPath
 from lxml import etree
 from lxml.builder import E
 from rasterio import crs
 from rasterio.enums import Resampling
 from sertit import files, misc, rasters, vectors
-from sertit.rasters import XDS_TYPE
+from sertit.misc import ListEnum
 
-from eoreader import cache, cached_property, utils
+from eoreader import cache, utils
 from eoreader.bands import (
     BandNames,
-    OpticalBands,
-    SarBands,
+    SarBand,
+    SarBandMap,
+    SpectralBand,
+    SpectralBandMap,
     is_clouds,
     is_dem,
     is_index,
@@ -43,22 +47,32 @@ from eoreader.bands import (
     to_band,
 )
 from eoreader.exceptions import InvalidBandError, InvalidProductError, InvalidTypeError
-from eoreader.products.product import Product, SensorType
-from eoreader.reader import Platform
-from eoreader.utils import DATETIME_FMT, EOREADER_NAME
+from eoreader.products.product import OrbitDirection, Product, SensorType
+from eoreader.reader import Constellation
+from eoreader.utils import DATETIME_FMT, EOREADER_NAME, simplify
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
-# -- CUSTOM FIELDS --
-NAME = "name"
-SENSOR_TYPE = "sensor_type"
-ACQ_DATETIME = "acquisition_datetime"
-BAND_MAP = "band_map"
-PLATFORM = "platform"
-DEF_RES = "default_resolution"
-PROD_TYPE = "product_type"
-SUN_AZ = "sun_azimuth"
-SUN_ZEN = "sun_zenith"
+
+@unique
+class CustomFields(ListEnum):
+    """
+    Custom fields, self explanatory
+    """
+
+    NAME = "name"
+    SENSOR_TYPE = "sensor_type"
+    DATETIME = "datetime"
+    BAND_MAP = "band_map"
+    CONSTELLATION = "constellation"
+    INSTRUMENT = "instrument"
+    RES = "resolution"
+    PROD_TYPE = "product_type"
+    SUN_AZ = "sun_azimuth"
+    SUN_ZEN = "sun_zenith"
+    ORBIT_DIR = "orbit_direction"
+    CC = "cloud_cover"
+
 
 # -- CUSTOM
 CUSTOM = "CUSTOM"
@@ -75,14 +89,16 @@ class CustomProduct(Product):
         remove_tmp: bool = False,
         **kwargs,
     ) -> None:
-        self.sun_az = None
-        """Sun mean angles (azimuth)"""
-
-        self.sun_zen = None
-        """Sun mean angles (zenith)"""
+        self.kwargs = kwargs
+        """Custom kwargs"""
 
         # Initialization from the super class
-        super().__init__(product_path, archive_path, output_path, remove_tmp, **kwargs)
+        # (Custom products arte managing constellation on their own)
+        super_kwargs = kwargs.copy()
+        super_kwargs.pop("constellation", None)
+        super().__init__(
+            product_path, archive_path, output_path, remove_tmp, **super_kwargs
+        )
 
     def _pre_init(self, **kwargs) -> None:
         """
@@ -92,20 +108,50 @@ class CustomProduct(Product):
         self.needs_extraction = False
 
         # -- Parse the kwargs
-        misc.check_mandatory_keys(kwargs, [BAND_MAP, SENSOR_TYPE])
-
-        # Sensor type
-        self.sensor_type = SensorType.convert_from(kwargs[SENSOR_TYPE])[0]
-        self.band_names = (
-            OpticalBands() if self.sensor_type == SensorType.OPTICAL else SarBands()
+        misc.check_mandatory_keys(
+            kwargs, [CustomFields.BAND_MAP.value, CustomFields.SENSOR_TYPE.value]
         )
 
+        # Process kwargs
+        for key in self.kwargs.keys():
+            try:
+                CustomFields.from_value(key)  # noqa
+            except ValueError:
+                LOGGER.warning(
+                    f"{key} is not taken into account as it doesn't belong to the handled keys: {CustomFields.list_values()}"
+                )
+
+        # Sensor type
+        self.sensor_type = SensorType.convert_from(
+            kwargs.pop(CustomFields.SENSOR_TYPE.value)
+        )[0]
+
+    def _map_bands(self):
+        """
+        Map bands
+        """
+        if self.sensor_type == SensorType.OPTICAL:
+            band_map = SpectralBandMap()
+            band = SpectralBand
+        else:
+            band_map = SarBandMap()
+            band = SarBand
+
+        self.bands = band_map
+
         # Band map
-        band_names = kwargs[BAND_MAP]  # Shouldn't be empty
+        band_names = self.kwargs.pop(CustomFields.BAND_MAP.value)  # Shouldn't be empty
         assert isinstance(band_names, dict)
-        band_names = {to_band(key)[0]: val for key, val in band_names.items()}
-        assert [is_sat_band(band) for band in band_names.keys()]
-        self.band_names.map_bands(band_names)
+
+        band_map = {}
+        for key, val in band_names.items():
+            assert is_sat_band(key), "Custom bands should be satellite band"
+            band_name = to_band(key)[0]
+            band_map[band_name] = band(
+                eoreader_name=band_name, name=band_name.value, id=val
+            )
+
+        self.bands.map_bands(band_map)
 
         # Test on the product
         with rasterio.open(str(self.get_default_band_path())) as ds:
@@ -113,25 +159,6 @@ class CustomProduct(Product):
                 len(band_names) == ds.count
             ), f"You should specify {ds.count} bands in band_map, not {len(band_names)} !"
 
-        # Datetime
-        self.datetime = kwargs.get(ACQ_DATETIME, datetime.now())
-        if isinstance(self.datetime, str):
-            try:
-                self.datetime = datetime.fromisoformat(self.datetime)
-            except ValueError:
-                self.datetime = datetime.strptime(self.datetime, "%Y%m%dT%H%M%S")
-        assert isinstance(self.datetime, datetime)
-
-        # Sun angles
-        self.sun_az = kwargs.get(SUN_AZ, None)
-        self.sun_zen = kwargs.get(SUN_ZEN, None)
-
-        # Others
-        self.name = kwargs.get(NAME, files.get_filename(self.path))
-        self.platform = Platform.convert_from(kwargs.get(PLATFORM, CUSTOM))[0]
-        self.resolution = kwargs.get(DEF_RES, None)
-        self.product_type = kwargs.get(PROD_TYPE, CUSTOM)
-
     def _post_init(self, **kwargs) -> None:
         """
         Function used to post_init the products
@@ -139,18 +166,18 @@ class CustomProduct(Product):
         """
         # Check CRS
         try:
-            crs = self.crs  # noqa
+            crs = self.crs()  # noqa
         except InvalidProductError as msg:
             LOGGER.warning(msg)
 
-    def _get_name(self) -> str:
+    def _get_name_constellation_specific(self) -> str:
         """
         Set product real name from metadata
 
         Returns:
             str: True name of the product (from metadata)
         """
-        return self.name
+        return self.kwargs.get(CustomFields.NAME.value, files.get_filename(self.path))
 
     def get_datetime(self, as_datetime: bool = False) -> str:
         """
@@ -159,29 +186,51 @@ class CustomProduct(Product):
         Returns:
             str: True name of the product (from metadata)
         """
+
+        # Datetime
+        dt = self.kwargs.get(CustomFields.DATETIME.value, datetime.now())
+        if isinstance(dt, str):
+            try:
+                dt = datetime.fromisoformat(dt)
+            except ValueError:
+                dt = datetime.strptime(dt, "%Y%m%dT%H%M%S")
+        assert isinstance(dt, datetime)
+
         if as_datetime:
-            date = self.datetime
+            date = dt
         else:
-            date = self.datetime.strftime(DATETIME_FMT)
+            date = dt.strftime(DATETIME_FMT)
 
         return date
 
-    def _get_platform(self) -> Platform:
-        return self.platform
+    def _get_constellation(self) -> Constellation:
+        return Constellation.convert_from(
+            self.kwargs.get(CustomFields.CONSTELLATION.value, CUSTOM)
+        )[0]
 
-    def _set_resolution(self) -> float:
+    def _get_resolution(self) -> float:
         """
-        Set product default resolution (in meters)
+        Get product default resolution (in meters)
         """
-        if self.resolution is None:
+        resolution = self.kwargs.get(CustomFields.RES.value, None)
+        if resolution is None:
             with rasterio.open(str(self.get_default_band_path())) as ds:
                 return ds.res[0]
         else:
-            return self.resolution
+            return resolution
+
+    def _set_instrument(self) -> None:
+        """
+        Set instrument
+
+        TSX+TDX: https://earth.esa.int/eogateway/missions/terrasar-x-and-tandem-x
+        PAZ: https://earth.esa.int/eogateway/missions/paz
+        """
+        self.instrument = self.kwargs.get(CustomFields.INSTRUMENT.value, CUSTOM)
 
     def _set_product_type(self) -> None:
         """Set products type"""
-        pass
+        self.product_type = self.kwargs.get(CustomFields.PROD_TYPE.value, CUSTOM)
 
     def get_default_band(self) -> BandNames:
         """
@@ -203,18 +252,19 @@ class CustomProduct(Product):
         """
         return self.path
 
-    @cached_property
+    @cache
     def extent(self) -> gpd.GeoDataFrame:
         """
         Get UTM extent of stack.
 
         Returns:
-            gpd.GeoDataFrame: Footprint in UTM
+            gpd.GeoDataFrame: Extent in UTM
         """
         # Get extent
-        return rasters.get_extent(self.get_default_band_path()).to_crs(self.crs)
+        return rasters.get_extent(self.get_default_band_path()).to_crs(self.crs())
 
-    @cached_property
+    @cache
+    @simplify
     def footprint(self) -> gpd.GeoDataFrame:
         """
         Get UTM footprint of the products (without nodata, *in french == emprise utile*)
@@ -224,16 +274,17 @@ class CustomProduct(Product):
             >>> from eoreader.reader import Reader
             >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
             >>> prod = Reader().open(path)
-            >>> prod.footprint
+            >>> prod.footprint()
                index                                           geometry
             0      0  POLYGON ((199980.000 4500000.000, 199980.000 4...
 
         Returns:
             gpd.GeoDataFrame: Footprint as a GeoDataFrame
         """
-        return rasters.get_footprint(self.get_default_band_path()).to_crs(self.crs)
+        arr = rasters.read(self.get_default_band_path(), indexes=[1])
+        return rasters.get_footprint(arr).to_crs(self.crs())
 
-    @cached_property
+    @cache
     def crs(self) -> crs.CRS:
         """
         Get UTM projection of stack.
@@ -296,7 +347,7 @@ class CustomProduct(Product):
         Returns:
             list: List of existing bands in the products
         """
-        return [name for name, nb in self.band_names.items() if nb]
+        return [name for name, nb in self.bands.items() if nb]
 
     # unused band_name (compatibility reasons)
     # pylint: disable=W0613
@@ -307,7 +358,7 @@ class CustomProduct(Product):
         resolution: Union[tuple, list, float] = None,
         size: Union[list, tuple] = None,
         **kwargs,
-    ) -> XDS_TYPE:
+    ) -> xr.DataArray:
         """
         Read band from disk.
 
@@ -321,7 +372,7 @@ class CustomProduct(Product):
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
             kwargs: Other arguments used to load bands
         Returns:
-            XDS_TYPE: Band xarray
+            xr.DataArray: Band xarray
 
         """
         return utils.read(
@@ -329,7 +380,7 @@ class CustomProduct(Product):
             resolution=resolution,
             size=size,
             resampling=Resampling.bilinear,
-            indexes=[self.band_names[band]],
+            indexes=[self.bands[band].id],
             **kwargs,
         ).astype(np.float32)
 
@@ -429,6 +480,28 @@ class CustomProduct(Product):
 
         return bands
 
+    @cache
+    def get_mean_sun_angles(self) -> (float, float):
+        """
+        Get Mean Sun angles (Azimuth and Zenith angles)
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_mean_sun_angles()
+            (149.148155074489, 32.6627897525474)
+
+        Returns:
+            (float, float): Mean Azimuth and Zenith angle
+        """
+        # Sun angles
+        sun_az = self.kwargs.get(CustomFields.SUN_AZ.value, None)
+        sun_zen = self.kwargs.get(CustomFields.SUN_ZEN.value, None)
+
+        return sun_az, sun_zen
+
     def _compute_hillshade(
         self,
         dem_path: str = "",
@@ -447,7 +520,8 @@ class CustomProduct(Product):
         Returns:
             str: Hillshade mask path
         """
-        if self.sun_az is not None and self.sun_zen is not None:
+        sun_az, sun_zen = self.get_mean_sun_angles()
+        if sun_az is not None and sun_zen is not None:
             # Warp DEM
             warped_dem_path = self._warp_dem(dem_path, resolution, size, resampling)
 
@@ -468,14 +542,12 @@ class CustomProduct(Product):
                 LOGGER.debug("Computing hillshade DEM for %s", self.name)
 
                 # Compute hillshade
-                hillshade = rasters.hillshade(
-                    warped_dem_path, self.sun_az, self.sun_zen
-                )
+                hillshade = rasters.hillshade(warped_dem_path, sun_az, sun_zen)
                 utils.write(hillshade, hillshade_path)
 
         else:
             raise InvalidProductError(
-                f"You should provide {SUN_AZ} and {SUN_ZEN} data to compute hillshade!"
+                f"You should provide {CustomFields.SUN_AZ.value} and {CustomFields.SUN_ZEN.value} data to compute hillshade!"
             )
 
         return hillshade_path
@@ -489,12 +561,17 @@ class CustomProduct(Product):
 
     def _get_condensed_name(self) -> str:
         """
-        Get products condensed name ({acq_datetime}_{platform}_{product_type}).
+        Get products condensed name ({acq_datetime}_{constellation}_{product_type}).
 
         Returns:
             str: Condensed name
         """
-        return f"{self.get_datetime()}_{self.platform.name}_{self.product_type}"
+        const = (
+            self.constellation
+            if isinstance(self.constellation, str)
+            else self.constellation.name
+        )
+        return f"{self.get_datetime()}_{const}_{self.product_type}"
 
     @cache
     def _read_mtd(self) -> (etree._Element, dict):
@@ -505,34 +582,32 @@ class CustomProduct(Product):
             (etree._Element, dict): Metadata XML root and its namespace
         """
         # Parsing global attributes
-        global_attr_names = [
-            "name",
-            "datetime",
-            "sensor_type",
-            "platform",
-            "resolution",
-            "product_type",
-            "band_names",
-            "sun_az",
-            "sun_zen",
-        ]
+        global_attr_names = CustomFields.list_values()
 
         # Create XML attributes
         global_attr = []
         for attr in global_attr_names:
-            if hasattr(self, attr):
-                if attr == "band_names":
-                    str_attr = str(
-                        {
-                            key.name: val
-                            for key, val in self.band_names.items()
-                            if isinstance(val, int)
-                        }
-                    )
+            if attr == CustomFields.BAND_MAP.value:
+                str_attr = str(
+                    {
+                        key.name: val.id
+                        for key, val in self.bands.items()
+                        if val is not None
+                    }
+                )
+            elif hasattr(self, attr):
+                # Get it formatted
+                val = getattr(self, attr)
+                if isinstance(val, ListEnum):
+                    str_attr = val.value
+                elif isinstance(val, datetime):
+                    str_attr = val.isoformat()
                 else:
-                    str_attr = str(getattr(self, attr))
+                    str_attr = str(val)
+            else:
+                str_attr = str(self.kwargs.get(attr, None))
 
-                global_attr.append(E(attr, str_attr))
+            global_attr.append(E(attr, str_attr))
 
         mtd = E.custom_metadata(*global_attr)
         mtd_el = etree.fromstring(
@@ -542,3 +617,48 @@ class CustomProduct(Product):
         )
 
         return mtd_el, {}
+
+    @cache
+    def get_orbit_direction(self) -> OrbitDirection:
+        """
+        Get cloud cover as given in the metadata
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_orbit_direction().value
+            "DESCENDING"
+
+        Returns:
+            OrbitDirection: Orbit direction (ASCENDING/DESCENDING)
+        """
+        od = self.kwargs.get(CustomFields.ORBIT_DIR.value, None)
+        if od is not None:
+            od = OrbitDirection.from_value(od)
+
+        return od
+
+    def _update_attrs_constellation_specific(
+        self, xarr: xr.DataArray, long_name: Union[str, list], **kwargs
+    ) -> xr.DataArray:
+        """
+        Update attributes of the given array (constellation specific)
+
+        Args:
+            xarr (xr.DataArray): Array whose attributes need an update
+            long_name (str): Array name (as a str or a list)
+        Returns:
+            xr.DataArray: Updated array
+        """
+        return xarr
+
+    def _to_repr_constellation_specific(self) -> list:
+        """
+        Representation specific to the constellation
+
+        Returns:
+            list: Representation list (constellation specific)
+        """
+        return []
