@@ -21,7 +21,6 @@ for more information.
 """
 import logging
 import time
-from abc import abstractmethod
 from datetime import date, datetime
 from enum import unique
 from pathlib import Path
@@ -31,24 +30,48 @@ import affine
 import geopandas as gpd
 import numpy as np
 import rasterio
+import xarray as xr
 from cloudpathlib import CloudPath
 from lxml import etree
 from rasterio import crs as riocrs
 from rasterio import features, transform
 from sertit import files, rasters_rio, vectors
 from sertit.misc import ListEnum
-from sertit.rasters import XDS_TYPE
+from shapely.geometry import Polygon, box
 
-from eoreader import cache, cached_property, utils
+from eoreader import cache, utils
 from eoreader.bands import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, SHADOWS, BandNames
-from eoreader.bands import OpticalBandNames as obn
+from eoreader.bands import spectral_bands as spb
 from eoreader.bands import to_str
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.products import VhrProduct
+from eoreader.reader import Constellation
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
+_DIMAP_BAND_MTD = {
+    spb.PAN: "P",
+    spb.BLUE: "B0",
+    spb.GREEN: "B1",
+    spb.RED: "B2",
+    spb.NIR: "B3",
+    spb.NARROW_NIR: "B3",
+}
+
+_PNEO_BAND_MTD = {
+    spb.PAN: "P",
+    spb.BLUE: "B",
+    spb.GREEN: "G",
+    spb.RED: "R",
+    spb.NIR: "NIR",
+    spb.NARROW_NIR: "NIR",
+    spb.VRE_1: "RE",
+    spb.VRE_2: "RE",
+    spb.VRE_3: "RE",
+    spb.CA: "DB",  # deep blue
+}
+
 
 @unique
 class DimapProductType(ListEnum):
@@ -92,6 +115,41 @@ class DimapProductType(ListEnum):
     """
 
 
+@unique
+class DimapRadiometricProcessing(ListEnum):
+    """
+    DIMAP V2 radiometric processing.
+
+    See `here <https://engesat.com.br/wp-content/uploads/PleiadesUserGuide-17062019.pdf>`_
+    (Paragraph 2.4) for more information.
+    """
+
+    BASIC = "BASIC"
+    """
+    In the BASIC radiometric option, the imagery values are digital numbers (DN)
+    quantifying the energy recorded by the detector corrected relative
+    to the other detectors to avoid non-uniformity noise.
+    """
+
+    REFLECTANCE = "REFLECTANCE"
+    """
+    In the REFLECTANCE radiometric option, the imagery values are corrected
+    from radiometric sensor calibration and systematic effects of the atmosphere
+    (molecular or Rayleigh diffusion and given in reflectance physical unit).
+    """
+
+    LINEAR_STRETCH = "LINEAR_STRETCH"
+    """
+    Relates to the BASIC option at 8-bit depth.
+    """
+
+    SEAMLESS = "SEAMLESS"
+    """
+    Relates to the mosaic option.
+    In this case, the spectral properties cannot be retrieved since the initial images have undergone several radiometric adjustments for aesthetic rendering.
+    """
+
+
 @unique
 class DimapBandCombination(ListEnum):
     """
@@ -174,24 +232,27 @@ class DimapProduct(VhrProduct):
         archive_path: Union[str, CloudPath, Path] = None,
         output_path: Union[str, CloudPath, Path] = None,
         remove_tmp: bool = False,
+        **kwargs,
     ) -> None:
         self._empty_mask = []
+        self._altitude = None
 
         # Initialization from the super class
-        super().__init__(product_path, archive_path, output_path, remove_tmp)
+        super().__init__(product_path, archive_path, output_path, remove_tmp, **kwargs)
 
-    def _pre_init(self) -> None:
+    def _pre_init(self, **kwargs) -> None:
         """
         Function used to pre_init the products
         (setting needs_extraction and so on)
         """
+        self._has_cloud_cover = True
         self.needs_extraction = False
         self._proj_prod_type = [DimapProductType.SEN, DimapProductType.PRJ]
 
         # Post init done by the super class
-        super()._pre_init()
+        super()._pre_init(**kwargs)
 
-    def _post_init(self) -> None:
+    def _post_init(self, **kwargs) -> None:
         """
         Function used to post_init the products
         (setting sensor type, band names and so on)
@@ -206,59 +267,140 @@ class DimapProduct(VhrProduct):
         self.band_combi = getattr(DimapBandCombination, band_combi.replace("-", "_"))
 
         # Post init done by the super class
-        super()._post_init()
+        super()._post_init(**kwargs)
 
-    @abstractmethod
-    def _set_resolution(self) -> float:
+    def _get_resolution(self) -> float:
         """
-        Set product default resolution (in meters)
+        Get product default resolution (in meters)
         """
-        raise NotImplementedError
+        # Not Pansharpened images
+        if self.band_combi in [
+            DimapBandCombination.MS,
+            DimapBandCombination.MS_X,
+            DimapBandCombination.MS_N,
+            DimapBandCombination.MS_FS,
+        ]:
+            return self._ms_res
+        # Pansharpened images
+        else:
+            return self._pan_res
 
-    def _set_product_type(self) -> None:
-        """Set products type"""
-        # Get MTD XML file
-        prod_type = self.split_name[3]
-        self.product_type = getattr(DimapProductType, prod_type)
+    def _map_bands_core(self, **kwargs) -> None:
+        """
+        Map bands
+        """
+        # Open spectral bands
+        pan = kwargs.get("pan")
+        blue = kwargs.get("blue")
+        green = kwargs.get("green")
+        red = kwargs.get("red")
+        nir = kwargs.get("nir")
+        ca = kwargs.get("ca")
+        vre = kwargs.get("vre")
 
         # Manage bands of the product
         if self.band_combi == DimapBandCombination.P:
-            self.band_names.map_bands({obn.PAN: 1})
-        elif self.band_combi in [DimapBandCombination.MS, DimapBandCombination.PMS]:
-            self.band_names.map_bands(
-                {obn.BLUE: 3, obn.GREEN: 2, obn.RED: 1, obn.NIR: 4, obn.NARROW_NIR: 4}
-            )
-        elif self.band_combi in [
-            DimapBandCombination.MS_N,
-            DimapBandCombination.PMS_N,
-            DimapBandCombination.PMS_FS,
-        ]:
-            self.band_names.map_bands({obn.BLUE: 3, obn.GREEN: 2, obn.RED: 1})
-        elif self.band_combi in [
-            DimapBandCombination.MS_FS,
-            DimapBandCombination.PMS_FS,
-        ]:
-            self.band_names.map_bands(
+            self.bands.map_bands({spb.PAN: pan.update(id=1)})
+        elif self.band_combi == DimapBandCombination.MS:
+            self.bands.map_bands(
                 {
-                    obn.BLUE: 3,
-                    obn.GREEN: 2,
-                    obn.RED: 1,
-                    obn.NIR: 4,
-                    obn.VRE_1: 5,
-                    obn.VRE_2: 5,
-                    obn.VRE_3: 5,
-                    obn.CA: 6,
+                    spb.BLUE: blue.update(id=3),
+                    spb.GREEN: green.update(id=2),
+                    spb.RED: red.update(id=1),
+                    spb.NARROW_NIR: nir.update(id=4),
+                    spb.NIR: nir.update(id=4),
                 }
             )
-        elif self.band_combi in [DimapBandCombination.MS_X, DimapBandCombination.PMS_X]:
-            self.band_names.map_bands(
-                {obn.GREEN: 1, obn.RED: 2, obn.NIR: 3, obn.NARROW_NIR: 3}
+        elif self.band_combi == DimapBandCombination.PMS:
+            self.bands.map_bands(
+                {
+                    spb.BLUE: blue.update(id=3, gsd=self._pan_res),
+                    spb.GREEN: green.update(id=2, gsd=self._pan_res),
+                    spb.RED: red.update(id=1, gsd=self._pan_res),
+                    spb.NARROW_NIR: nir.update(id=4, gsd=self._pan_res),
+                    spb.NIR: nir.update(id=4, gsd=self._pan_res),
+                }
+            )
+        elif self.band_combi == DimapBandCombination.MS_N:
+            self.bands.map_bands(
+                {
+                    spb.BLUE: blue.update(id=3),
+                    spb.GREEN: green.update(id=2),
+                    spb.RED: red.update(id=1),
+                }
+            )
+        elif self.band_combi == DimapBandCombination.PMS_N:
+            self.bands.map_bands(
+                {
+                    spb.BLUE: blue.update(id=3, gsd=self._pan_res),
+                    spb.GREEN: green.update(id=2, gsd=self._pan_res),
+                    spb.RED: red.update(id=1, gsd=self._pan_res),
+                }
+            )
+        elif self.band_combi == DimapBandCombination.MS_X:
+            self.bands.map_bands(
+                {
+                    spb.GREEN: green.update(id=1),
+                    spb.RED: red.update(id=2),
+                    spb.NIR: nir.update(id=3),
+                    spb.NARROW_NIR: nir.update(id=3),
+                }
+            )
+        elif self.band_combi == DimapBandCombination.PMS_X:
+            self.bands.map_bands(
+                {
+                    spb.GREEN: green.update(id=1, gsd=self._pan_res),
+                    spb.RED: red.update(id=2, gsd=self._pan_res),
+                    spb.NIR: nir.update(id=3, gsd=self._pan_res),
+                    spb.NARROW_NIR: nir.update(id=3, gsd=self._pan_res),
+                }
+            )
+        elif self.band_combi == DimapBandCombination.MS_FS:
+            # Only PLD-Neo
+            self.bands.map_bands(
+                {
+                    spb.BLUE: blue.update(id=3),
+                    spb.GREEN: green.update(id=2),
+                    spb.RED: red.update(id=1),
+                    spb.NIR: nir.update(id=4),
+                    spb.NARROW_NIR: nir.update(id=4),
+                    spb.VRE_1: vre.update(id=5),
+                    spb.VRE_2: vre.update(id=5),
+                    spb.VRE_3: vre.update(id=5),
+                    spb.CA: ca.update(id=6),
+                }
+            )
+        elif self.band_combi == DimapBandCombination.PMS_FS:
+            # Only PLD-Neo
+            self.bands.map_bands(
+                {
+                    spb.BLUE: blue.update(id=3, gsd=self._pan_res),
+                    spb.GREEN: green.update(id=2, gsd=self._pan_res),
+                    spb.RED: red.update(id=1, gsd=self._pan_res),
+                    spb.NIR: nir.update(id=4, gsd=self._pan_res),
+                    spb.NARROW_NIR: nir.update(id=4, gsd=self._pan_res),
+                    spb.VRE_1: vre.update(id=5, gsd=self._pan_res),
+                    spb.VRE_2: vre.update(id=5, gsd=self._pan_res),
+                    spb.VRE_3: vre.update(id=5, gsd=self._pan_res),
+                    spb.CA: ca.update(id=6, gsd=self._pan_res),
+                }
             )
         else:
             raise InvalidProductError(
                 f"Unusual band combination: {self.band_combi.name}"
             )
 
+    def _set_product_type(self) -> None:
+        """Set products type"""
+
+        # get product type
+        prod_type = self.split_name[3]
+        self.product_type = getattr(DimapProductType, prod_type)
+
+        # Manage not orthorectified product
+        if self.product_type in [DimapProductType.SEN, DimapProductType.PRJ]:
+            self.is_ortho = False
+
     def _get_raw_crs(self) -> riocrs.CRS:
         """
         Get raw CRS of the tile
@@ -280,7 +422,7 @@ class DimapProduct(VhrProduct):
 
         return riocrs.CRS.from_string(crs_name)
 
-    @cached_property
+    @cache
     def crs(self) -> riocrs.CRS:
         """
         Get UTM projection of the tile
@@ -290,7 +432,7 @@ class DimapProduct(VhrProduct):
             >>> from eoreader.reader import Reader
             >>> path = r"IMG_PHR1B_PMS_001"
             >>> prod = Reader().open(path)
-            >>> prod.crs
+            >>> prod.crs()
             CRS.from_epsg(32618)
 
         Returns:
@@ -300,7 +442,7 @@ class DimapProduct(VhrProduct):
         root, _ = self.read_mtd()
 
         # Open the Bounding_Polygon
-        vertices = [v for v in root.iterfind(".//Vertex")]
+        vertices = list(root.iterfind(".//Vertex"))
 
         # Get the mean lon lat
         lon = float(np.mean([float(v.findtext("LON")) for v in vertices]))
@@ -312,28 +454,39 @@ class DimapProduct(VhrProduct):
 
         return utm
 
-    @cached_property
+    @cache
     def extent(self, **kwargs) -> gpd.GeoDataFrame:
         """
-        Get real footprint in UTM of the products (without nodata, in french == emprise utile)
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"IMG_PHR1B_PMS_001"
-            >>> prod = Reader().open(path)
-            >>> prod.footprint
-                                                         gml_id  ...                                           geometry
-            0  source_image_footprint-DS_PHR1A_20200511023124...  ...  POLYGON ((707025.261 9688613.833, 707043.276 9...
-            [1 rows x 3 columns]
+        Get UTM extent of the tile.
 
         Returns:
-            gpd.GeoDataFrame: Footprint as a GeoDataFrame
+            gpd.GeoDataFrame: Extent in UTM
         """
-        # TODO: parse KMZ - product - xxxx ?
-        return super().extent
+        # Get MTD XML file
+        root, _ = self.read_mtd()
 
-    @cached_property
+        # Compute extent corners
+        corners = [
+            [float(vertex.findtext("LON")), float(vertex.findtext("LAT"))]
+            for vertex in root.iterfind(".//Dataset_Extent/Vertex")
+        ]
+
+        extent_wgs84 = gpd.GeoDataFrame(
+            geometry=[Polygon(corners)],
+            crs=vectors.WGS84,
+        )
+
+        # Not square extent
+        utm_extent_raw = extent_wgs84.to_crs(self.crs())
+
+        utm_extent = gpd.GeoDataFrame(
+            geometry=[box(*utm_extent_raw.total_bounds)],
+            crs=self.crs(),
+        )
+
+        return utm_extent
+
+    @cache
     def footprint(self, **kwargs) -> gpd.GeoDataFrame:
         """
         Get real footprint in UTM of the products (without nodata, in french == emprise utile)
@@ -343,7 +496,7 @@ class DimapProduct(VhrProduct):
             >>> from eoreader.reader import Reader
             >>> path = r"IMG_PHR1B_PMS_001"
             >>> prod = Reader().open(path)
-            >>> prod.footprint
+            >>> prod.footprint()
                                                          gml_id  ...                                           geometry
             0  source_image_footprint-DS_PHR1A_20200511023124...  ...  POLYGON ((707025.261 9688613.833, 707043.276 9...
             [1 rows x 3 columns]
@@ -351,7 +504,7 @@ class DimapProduct(VhrProduct):
         Returns:
             gpd.GeoDataFrame: Footprint as a GeoDataFrame
         """
-        return self.open_mask("ROI", **kwargs).to_crs(self.crs)
+        return self.open_mask("ROI", **kwargs).to_crs(self.crs())
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
         """
@@ -411,7 +564,7 @@ class DimapProduct(VhrProduct):
 
         return date_str
 
-    def _get_name(self) -> str:
+    def _get_name_constellation_specific(self) -> str:
         """
         Set product real name from metadata
 
@@ -421,21 +574,18 @@ class DimapProduct(VhrProduct):
         return files.get_filename(self._get_tile_path()).replace("DIM_", "")
 
     def _manage_invalid_pixels(
-        self, band_arr: XDS_TYPE, band: obn, **kwargs
-    ) -> XDS_TYPE:
+        self, band_arr: xr.DataArray, band: BandNames, **kwargs
+    ) -> xr.DataArray:
         """
         Manage invalid pixels (Nodata, saturated, defective...)
-        See
-        `here <https://earth.esa.int/eogateway/documents/20142/37627/Planet-combined-imagery-product-specs-2020.pdf>`_
-        (unusable data mask) for more information.
 
         Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
+            band_arr (xr.DataArray): Band array
+            band (BandNames): Band name as a SpectralBandNames
             kwargs: Other arguments used to load bands
 
         Returns:
-            XDS_TYPE: Cleaned band array
+            xr.DataArray: Cleaned band array
         """
         # array data
         width = band_arr.rio.width
@@ -471,17 +621,77 @@ class DimapProduct(VhrProduct):
 
         return self._set_nodata_mask(band_arr, nodata)
 
-    def _manage_nodata(self, band_arr: XDS_TYPE, band: obn, **kwargs) -> XDS_TYPE:
+    def _to_reflectance(
+        self,
+        band_arr: xr.DataArray,
+        path: Union[Path, CloudPath],
+        band: BandNames,
+        **kwargs,
+    ) -> xr.DataArray:
+        """
+        Converts band to reflectance
+
+        See
+        `here <https://www.intelligence-airbusds.com/automne/api/docs/v1.0/document/download/ZG9jdXRoZXF1ZS1kb2N1bWVudC01NTY0Mw==/ZG9jdXRoZXF1ZS1maWxlLTU1NjQy/airbus-pleiades-imagery-user-guide-15042021.pdf>`_
+        (Appendix D)
+
+        Args:
+            band_arr (xr.DataArray):
+            path (Union[Path, CloudPath]):
+            band (BandNames):
+            **kwargs: Other keywords
+
+        Returns:
+            xr.DataArray: Band in reflectance
+        """
+        # Get MTD XML file
+        root, _ = self.read_mtd()
+        rad_proc = DimapRadiometricProcessing.from_value(
+            root.findtext(".//RADIOMETRIC_PROCESSING")
+        )
+
+        if rad_proc == DimapRadiometricProcessing.REFLECTANCE:
+            # Compute the correct radiometry of the band
+            original_dtype = band_arr.encoding.get("dtype", band_arr.dtype)
+            if original_dtype == "uint16":
+                band_arr /= 10000.0
+        elif rad_proc in [
+            DimapRadiometricProcessing.BASIC,
+            DimapRadiometricProcessing.LINEAR_STRETCH,
+        ]:
+            # Convert DN into radiance
+            band_arr = self._dn_to_toa_rad(band_arr, band)
+
+            # Convert radiance into reflectance
+            band_arr = self._toa_rad_to_toa_refl(band_arr, band)
+
+        else:
+            LOGGER.warning(
+                "The spectral properties of a SEAMLESS radiometric processed image "
+                "cannot be retrieved since the initial images have undergone "
+                "several radiometric adjustments for aesthetic rendering."
+                "Returned as is."
+            )
+
+        # To float32
+        if band_arr.dtype != np.float32:
+            band_arr = band_arr.astype(np.float32)
+
+        return band_arr
+
+    def _manage_nodata(
+        self, band_arr: xr.DataArray, band: BandNames, **kwargs
+    ) -> xr.DataArray:
         """
         Manage only nodata pixels
 
         Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
+            band_arr (xr.DataArray): Band array
+            band (BandNames): Band name as an SpectralBandNames
             kwargs: Other arguments used to load bands
 
         Returns:
-            XDS_TYPE: Cleaned band array
+            xr.DataArray: Cleaned band array
         """
         # array data
         width = band_arr.rio.width
@@ -531,6 +741,62 @@ class DimapProduct(VhrProduct):
 
         return azimuth_angle, zenith_angle
 
+    @cache
+    def get_mean_viewing_angles(self) -> (float, float, float):
+        """
+        Get Mean Viewing angles (azimuth, off-nadir and incidence angles)
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_mean_viewing_angles()
+
+        Returns:
+            (float, float, float): Mean azimuth, off-nadir and incidence angles
+        """
+
+        def incidence_to_off_nadir(
+            incidence_angle: float, orbit_height: float = 695000
+        ) -> float:
+            """
+
+            Args:
+                incidence_angle:
+                orbit_height:
+
+            Returns:
+
+            """
+            earth_radius = 6378137
+            orbit_coeff = (earth_radius + orbit_height) / earth_radius
+            return np.rad2deg(
+                np.arcsin(np.sin(np.deg2rad(90 - incidence_angle)) / orbit_coeff)
+            )
+
+        # Get MTD XML file
+        root, _ = self.read_mtd()
+
+        # Open zenith and azimuth angle
+        try:
+            center_vals = [
+                a
+                for a in root.iterfind(".//Located_Geometric_Values")
+                if a.findtext("LOCATION_TYPE") == "Center"
+            ][0]
+            incidence_angle = float(center_vals.findtext(".//INCIDENCE_ANGLE"))
+            az = float(center_vals.findtext(".//AZIMUTH_ANGLE"))
+        except TypeError:
+            raise InvalidProductError("Azimuth or Zenith angles not found in metadata!")
+
+        # Compute off nadir angles
+        off_nadir = incidence_to_off_nadir(
+            incidence_angle=incidence_angle, orbit_height=self._altitude
+        )
+
+        return az, off_nadir, incidence_angle
+
     @cache
     def _read_mtd(self) -> (etree._Element, dict):
         """
@@ -588,7 +854,7 @@ class DimapProduct(VhrProduct):
                         dst,
                         resolution=resolution,
                         size=size,
-                        indexes=[self.band_names[self.get_default_band()]],
+                        indexes=[self.bands[self.get_default_band()].id],
                     )
                 else:
                     def_xarr = utils.read(dst, resolution=resolution, size=size)
@@ -670,7 +936,7 @@ class DimapProduct(VhrProduct):
         mandatory_masks = ["CLD", "DET", "QTE", "ROI", "SLT", "SNW"]
         optional_masks = ["VIS"]
         assert mask_str in mandatory_masks + optional_masks
-        crs = self.crs
+        crs = self.crs()
 
         mask_name = f"{self.condensed_name}_MSK_{mask_str}.geojson"
         mask_path = self._get_band_folder().joinpath(mask_name)
@@ -719,7 +985,7 @@ class DimapProduct(VhrProduct):
             ]:
                 LOGGER.info(f"Orthorectifying {mask_str}")
                 with rasterio.open(str(self._get_tile_path())) as dim_dst:
-                    # Rasterize mask (no transform as we have teh vector in image geometry)
+                    # Rasterize mask (no transform as we have the vector in image geometry)
                     LOGGER.debug(f"\tRasterizing {mask_str}")
                     mask_raster = features.rasterize(
                         mask.geometry,
@@ -744,6 +1010,9 @@ class DimapProduct(VhrProduct):
                         default_nodata=self._mask_false,
                     )
 
+                    # Do not keep pixelized mask
+                    mask = utils.simplify_footprint(mask, self.resolution)
+
             # Sometimes the GML mask lacks crs (why ?)
             elif (
                 not mask.empty
@@ -756,7 +1025,7 @@ class DimapProduct(VhrProduct):
             ):
                 # Convert to target CRS
                 mask.crs = self._get_raw_crs()
-                mask = mask.to_crs(self.crs)
+                mask = mask.to_crs(self.crs())
 
             # Save to file
             if mask.empty:
@@ -804,3 +1073,156 @@ class DimapProduct(VhrProduct):
 
         """
         return self._get_path("DIM_", "XML")
+
+    def _dn_to_toa_rad(self, dn_arr: xr.DataArray, band: BandNames) -> xr.DataArray:
+        """
+        Compute DN to TOA radiance
+
+        See
+        `here <https://www.intelligence-airbusds.com/automne/api/docs/v1.0/document/download/ZG9jdXRoZXF1ZS1kb2N1bWVudC01NTY0Mw==/ZG9jdXRoZXF1ZS1maWxlLTU1NjQy/airbus-pleiades-imagery-user-guide-15042021.pdf>`_
+        for more information. (Appendix D)
+
+        Args:
+            rad_arr (xr.DataArray): DN array
+            band (BandNames): Band
+
+        Returns:
+            xr.DataArray: TOA Radiance array
+        """
+        if self.constellation == Constellation.PNEO:
+            band_mtd_str = _PNEO_BAND_MTD[band]
+        else:
+            band_mtd_str = _DIMAP_BAND_MTD[band]
+
+        # Get MTD XML file
+        root, _ = self.read_mtd()
+
+        # Convert DN to TOA radiance
+        # <MEASURE_DESC>Raw radiometric counts (DN) to TOA Radiance (L). Formulae L=DN/GAIN+BIAS</MEASURE_DESC>
+        try:
+            rad_gain = None
+            rad_bias = None
+            for br in root.iterfind(".//Band_Radiance"):
+                if br.findtext("BAND_ID") == band_mtd_str:
+                    rad_gain = float(br.findtext("GAIN"))
+                    rad_bias = float(br.findtext("BIAS"))
+                    break
+
+            if rad_gain is None or rad_bias is None:
+                raise TypeError
+
+        except TypeError:
+            raise InvalidProductError(
+                "GAIN and BIAS from Band_Radiance not found in metadata!"
+            )
+        return dn_arr / rad_gain + rad_bias
+
+    def _toa_rad_to_toa_refl(
+        self, rad_arr: xr.DataArray, band: BandNames
+    ) -> xr.DataArray:
+        """
+        Compute TOA reflectance from TOA radiance
+
+        See
+        `here <https://www.intelligence-airbusds.com/automne/api/docs/v1.0/document/download/ZG9jdXRoZXF1ZS1kb2N1bWVudC01NTY0Mw==/ZG9jdXRoZXF1ZS1maWxlLTU1NjQy/airbus-pleiades-imagery-user-guide-15042021.pdf>`_
+        for more information. (Appendix D)
+
+        Args:
+            rad_arr (xr.DataArray): TOA Radiance array
+            band (BandNames): Band
+
+        Returns:
+            xr.DataArray: TOA Reflectance array
+        """
+        if self.constellation == Constellation.PNEO:
+            band_mtd_str = _PNEO_BAND_MTD[band]
+        else:
+            band_mtd_str = _DIMAP_BAND_MTD[band]
+
+        # Get MTD XML file
+        root, _ = self.read_mtd()
+
+        # Get the solar irradiance value of raw radiometric Band (in watt/m2/micron)
+        try:
+            e0 = None
+            for br in root.iterfind(".//Band_Solar_Irradiance"):
+                if br.findtext("BAND_ID") == band_mtd_str:
+                    e0 = float(br.findtext("VALUE"))
+                    break
+
+            if e0 is None:
+                raise TypeError
+
+        except TypeError:
+            raise InvalidProductError(
+                "VALUE from Band_Solar_Irradiance not found in metadata!"
+            )
+
+        # Compute the coefficient converting TOA radiance in TOA reflectance
+        dt = self._sun_earth_distance_variation()
+        _, sun_zen = self.get_mean_sun_angles()
+        rad_sun_zen = np.deg2rad(sun_zen)
+
+        # WARNING: d = 1 / sqrt(d(t))
+        toa_refl_coeff = np.pi / (e0 * dt * np.cos(rad_sun_zen))
+
+        # LOGGER.debug(f"rad to refl coeff = {toa_refl_coeff}")
+        return rad_arr.copy(data=toa_refl_coeff * rad_arr)
+
+    @cache
+    def get_cloud_cover(self) -> float:
+        """
+        Get cloud cover as given in the metadata
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_cloud_cover()
+            55.5
+
+        Returns:
+            float: Cloud cover as given in the metadata
+        """
+
+        # Get MTD XML file
+        root, _ = self.read_mtd()
+
+        # Get the cloud cover
+        try:
+            cc = float(root.findtext(".//CLOUD_COVERAGE"))
+
+        except TypeError:
+            raise InvalidProductError("CLOUD_COVERAGE not found in metadata!")
+
+        return cc
+
+    def get_quicklook_path(self) -> str:
+        """
+        Get quicklook path if existing.
+
+        Returns:
+            str: Quicklook path
+        """
+        quicklook_path = None
+        try:
+            if self.is_archived:
+                quicklook_path = files.get_archived_rio_path(
+                    self.path, file_regex=".*PREVIEW.*JPG"
+                )
+            else:
+                quicklook_path = str(next(self.path.glob("*PREVIEW*.JPG")))
+        except (StopIteration, FileNotFoundError):
+            LOGGER.warning(f"No quicklook found in {self.condensed_name}")
+
+        return quicklook_path
+
+    def _get_job_id(self) -> str:
+        """
+        Get VHR job ID
+
+        Returns:
+            str: VHR product ID
+        """
+        return self.split_name[-1]
