@@ -33,20 +33,27 @@ import xarray as xr
 from cloudpathlib import CloudPath
 from rasterio import features
 from rasterio.enums import Resampling
-from sertit import rasters, rasters_rio
+from sertit import files, rasters, rasters_rio
 from sertit.misc import ListEnum
-from sertit.rasters import MAX_CORES, XDS_TYPE
+from sertit.rasters import MAX_CORES
 from sertit.vectors import WGS84
 
 from eoreader import cache, utils
-from eoreader.bands import ALL_CLOUDS, CIRRUS, CLOUDS, RAW_CLOUDS, BandNames
-from eoreader.bands import OpticalBandNames as obn
+from eoreader.bands import (
+    ALL_CLOUDS,
+    CIRRUS,
+    CLOUDS,
+    RAW_CLOUDS,
+    BandNames,
+    SpectralBand,
+)
+from eoreader.bands import spectral_bands as spb
 from eoreader.bands import to_str
-from eoreader.exceptions import InvalidProductError, InvalidTypeError
+from eoreader.exceptions import InvalidTypeError
 from eoreader.keywords import CLEAN_OPTICAL, SLSTR_RAD_ADJUST, SLSTR_STRIPE, SLSTR_VIEW
-from eoreader.products import S3DataType, S3Instrument, S3Product, S3ProductType
+from eoreader.products import S3DataType, S3Product, S3ProductType
 from eoreader.products.optical.optical_product import DEF_CLEAN_METHOD, CleanMethod
-from eoreader.reader import Platform
+from eoreader.stac import ASSET_ROLE, BT, CENTER_WV, DESCRIPTION, FWHM, GSD, ID, NAME
 from eoreader.utils import EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -55,13 +62,13 @@ LOGGER = logging.getLogger(EOREADER_NAME)
 # https://github.com/senbox-org/s3tbx/blob/197c9a471002eb2ec1fbd54e9a31bfc963446645/s3tbx-rad2refl/src/main/java/org/esa/s3tbx/processor/rad2refl/Rad2ReflConstants.java#L141
 # Not used for now
 SLSTR_SOLAR_FLUXES_DEFAULT = {
-    obn.GREEN: 1837.39,
-    obn.RED: 1525.94,
-    obn.NIR: 956.17,
-    obn.NARROW_NIR: 956.17,
-    obn.SWIR_CIRRUS: 365.90,
-    obn.SWIR_1: 248.33,
-    obn.SWIR_2: 78.33,
+    spb.GREEN: 1837.39,
+    spb.RED: 1525.94,
+    spb.NIR: 956.17,
+    spb.NARROW_NIR: 956.17,
+    spb.SWIR_CIRRUS: 365.90,
+    spb.SWIR_1: 248.33,
+    spb.SWIR_2: 78.33,
 }
 
 # Link band names to their stripe
@@ -212,6 +219,7 @@ class S3SlstrProduct(S3Product):
         archive_path: Union[str, CloudPath, Path] = None,
         output_path: Union[str, CloudPath, Path] = None,
         remove_tmp: bool = False,
+        **kwargs,
     ) -> None:
         """
         https://sentinels.copernicus.eu/web/sentinel/technical-guides/sentinel-3-slstr/level-1/observation-mode-desc
@@ -239,24 +247,11 @@ class S3SlstrProduct(S3Product):
         self._bt_subds = "{band}_BT_{suffix}"
 
         super().__init__(
-            product_path, archive_path, output_path, remove_tmp
-        )  # Order is important here
+            product_path, archive_path, output_path, remove_tmp, **kwargs
+        )  # Order is important here, gcps NEED to be after this
 
         self._gcps = defaultdict(list)
 
-    def _get_platform(self) -> Platform:
-        """ Getter of the platform """
-        if "SL" in self.name:
-            # Instrument
-            self._instrument = S3Instrument.SLSTR
-            sat_id = self._instrument.value
-        else:
-            raise InvalidProductError(
-                f"Only OLCI and SLSTR are valid Sentinel-3 instruments : {self.name}"
-            )
-
-        return getattr(Platform, sat_id)
-
     def _get_preprocessed_band_path(
         self,
         filename: str,
@@ -316,9 +311,9 @@ class S3SlstrProduct(S3Product):
         # Other
         self._exception_name = "{band}_exception_{suffix}"
 
-    def _set_resolution(self) -> float:
+    def _get_resolution(self) -> float:
         """
-        Set product default resolution (in meters)
+        Get product default resolution (in meters)
         """
         return 500.0
 
@@ -331,27 +326,192 @@ class S3SlstrProduct(S3Product):
         self.product_type = S3ProductType.SLSTR_RBT
         self._data_type = S3DataType.RBT
 
+    def _map_bands(self) -> None:
+        """
+        Map bands
+        """
         # Bands
-        self.band_names.map_bands(
-            {
-                obn.GREEN: SLSTR_A_BANDS[0],  # S1, radiance, 500m
-                obn.RED: SLSTR_A_BANDS[1],  # S2, radiance, 500m
-                obn.NIR: SLSTR_A_BANDS[2],  # S3, radiance, 500m
-                obn.NARROW_NIR: SLSTR_A_BANDS[2],  # S3, radiance, 500m
-                obn.SWIR_CIRRUS: SLSTR_ABC_BANDS[0],  # S4, radiance, 500m
-                obn.SWIR_1: SLSTR_ABC_BANDS[1],  # S5, radiance, 500m
-                obn.SWIR_2: SLSTR_ABC_BANDS[2],  # S6, radiance, 500m
-                obn.S7: SLSTR_I_BANDS[0],  # S7, brilliance temperature, 1km
-                obn.TIR_1: SLSTR_I_BANDS[1],  # S8, brilliance temperature, 1km
-                obn.TIR_2: SLSTR_I_BANDS[2],  # S9, brilliance temperature, 1km
-                obn.F1: SLSTR_I_BANDS[3],  # F1, brilliance temperature, 1km
-                obn.F2: SLSTR_I_BANDS[4],  # F2, brilliance temperature, 1km
-            }
-        )
+        bt_res = 1000.0
+        slstr_bands = {
+            spb.GREEN: SpectralBand(
+                eoreader_name=spb.GREEN,
+                **{
+                    NAME: SLSTR_A_BANDS[0],
+                    ID: SLSTR_A_BANDS[0],
+                    GSD: self.resolution,
+                    CENTER_WV: 554.27,
+                    FWHM: 19.26,
+                    DESCRIPTION: "Cloud screening, vegetation monitoring, aerosol",
+                },
+            ),
+            spb.RED: SpectralBand(
+                eoreader_name=spb.RED,
+                **{
+                    NAME: SLSTR_A_BANDS[1],
+                    ID: SLSTR_A_BANDS[1],
+                    GSD: self.resolution,
+                    CENTER_WV: 659.47,
+                    FWHM: 19.25,
+                    DESCRIPTION: "NDVI, vegetation monitoring, aerosol",
+                },
+            ),
+            spb.NIR: SpectralBand(
+                eoreader_name=spb.NIR,
+                **{
+                    NAME: SLSTR_A_BANDS[2],
+                    ID: SLSTR_A_BANDS[2],
+                    GSD: self.resolution,
+                    CENTER_WV: 868.00,
+                    FWHM: 20.60,
+                    DESCRIPTION: "NDVI, cloud flagging, pixel co-registration",
+                },
+            ),
+            spb.NARROW_NIR: SpectralBand(
+                eoreader_name=spb.NARROW_NIR,
+                **{
+                    NAME: SLSTR_A_BANDS[2],
+                    ID: SLSTR_A_BANDS[2],
+                    GSD: self.resolution,
+                    CENTER_WV: 868.00,
+                    FWHM: 20.60,
+                    DESCRIPTION: "NDVI, cloud flagging, pixel co-registration",
+                },
+            ),
+            spb.SWIR_CIRRUS: SpectralBand(
+                eoreader_name=spb.SWIR_CIRRUS,
+                **{
+                    NAME: SLSTR_ABC_BANDS[0],
+                    ID: SLSTR_ABC_BANDS[0],
+                    GSD: self.resolution,
+                    CENTER_WV: 1374.80,
+                    FWHM: 20.80,
+                    DESCRIPTION: "Cirrus detection over land",
+                },
+            ),
+            spb.SWIR_1: SpectralBand(
+                eoreader_name=spb.SWIR_1,
+                **{
+                    NAME: SLSTR_ABC_BANDS[1],
+                    ID: SLSTR_ABC_BANDS[1],
+                    GSD: self.resolution,
+                    CENTER_WV: 1613.40,
+                    FWHM: 60.68,
+                    DESCRIPTION: "Cloud clearing, ice, snow, vegetation monitoring",
+                },
+            ),
+            spb.SWIR_2: SpectralBand(
+                eoreader_name=spb.SWIR_2,
+                **{
+                    NAME: SLSTR_ABC_BANDS[2],
+                    ID: SLSTR_ABC_BANDS[2],
+                    GSD: bt_res,
+                    CENTER_WV: 2255.70,
+                    FWHM: 50.15,
+                    DESCRIPTION: "Vegetation state and cloud clearing",
+                },
+            ),
+            spb.S7: SpectralBand(
+                eoreader_name=spb.S7,
+                **{
+                    NAME: SLSTR_I_BANDS[0],
+                    ID: SLSTR_I_BANDS[0],
+                    GSD: bt_res,
+                    CENTER_WV: 3742.00,
+                    FWHM: 398.00,
+                    DESCRIPTION: "SST, LST, Active fire, brilliance temperature, 1km",
+                    ASSET_ROLE: BT,
+                },
+            ),
+            spb.TIR_1: SpectralBand(
+                eoreader_name=spb.TIR_1,
+                **{
+                    NAME: SLSTR_I_BANDS[1],
+                    ID: SLSTR_I_BANDS[1],
+                    GSD: bt_res,
+                    CENTER_WV: 10854.00,
+                    FWHM: 776.00,
+                    DESCRIPTION: "SST, LST, Active fire, brilliance temperature, 1km",
+                    ASSET_ROLE: BT,
+                },
+            ),
+            spb.TIR_2: SpectralBand(
+                eoreader_name=spb.TIR_2,
+                **{
+                    NAME: SLSTR_I_BANDS[2],
+                    ID: SLSTR_I_BANDS[2],
+                    GSD: bt_res,
+                    CENTER_WV: 12022.50,
+                    FWHM: 905.00,
+                    DESCRIPTION: "SST, LST, brilliance temperature, 1km",
+                    ASSET_ROLE: BT,
+                },
+            ),
+            spb.F1: SpectralBand(
+                eoreader_name=spb.F1,
+                **{
+                    NAME: SLSTR_I_BANDS[3],
+                    ID: SLSTR_I_BANDS[3],
+                    GSD: bt_res,
+                    CENTER_WV: 3742.00,
+                    FWHM: 398.00,
+                    DESCRIPTION: "Active fire, brilliance temperature, 1km",
+                    ASSET_ROLE: BT,
+                },
+            ),
+            spb.F2: SpectralBand(
+                eoreader_name=spb.F2,
+                **{
+                    NAME: SLSTR_I_BANDS[4],
+                    ID: SLSTR_I_BANDS[4],
+                    GSD: bt_res,
+                    CENTER_WV: 10854.00,
+                    FWHM: 776.00,
+                    DESCRIPTION: "Active fire, brilliance temperature, 1km",
+                    ASSET_ROLE: BT,
+                },
+            ),
+        }
+
+        # Bands
+        self.bands.map_bands(slstr_bands)
+
+    def get_raw_band_paths(self, **kwargs) -> dict:
+        """
+        Return the raw band paths.
+
+        Args:
+            kwargs: Additional arguments
+
+        Returns:
+            dict: Dictionary containing the path of each queried band
+        """
+        raw_band_paths = {}
+        for band in self.get_existing_bands():
+            band_id = self.bands[band].id
+
+            # Get this band's suffix
+            suffix = kwargs.get("suffix", self._get_suffix(band, **kwargs))
+
+            # Get band filename and subdataset
+            if band_id in SLSTR_RAD_BANDS:
+                filename = self._replace(self._radiance_file, band=band, suffix=suffix)
+            elif band_id in SLSTR_BT_BANDS:
+                filename = self._replace(self._bt_file, band=band, suffix=suffix)
+            else:
+                filename = band
+
+            if self.is_archived:
+                raw_path = files.get_archived_path(self.path, f".*{filename}*")
+            else:
+                raw_path = next(self.path.glob(f"*{filename}*"))
+
+            raw_band_paths[band] = raw_path
+
+        return raw_band_paths
 
     def _preprocess(
         self,
-        band: Union[obn, str],
+        band: Union[BandNames, str],
         resolution: float = None,
         to_reflectance: bool = True,
         subdataset: str = None,
@@ -364,7 +524,7 @@ class S3SlstrProduct(S3Product):
         - Convert radiance to reflectance
 
         Args:
-            band (Union[obn, str]): Band to preprocess (quality flags or others are accepted)
+            band (Union[BandNames, str]): Band to preprocess (quality flags or others are accepted)
             resolution (float): Resolution
             to_reflectance (bool): Convert band to reflectance
             subdataset (str): Subdataset
@@ -373,11 +533,11 @@ class S3SlstrProduct(S3Product):
         Returns:
             dict: Dictionary containing {band: path}
         """
-        if isinstance(band, obn):
-            band_name = self.band_names[band]
+        if isinstance(band, BandNames):
+            band_id = self.bands[band].id
             band_str = band.name
         else:
-            band_name = band
+            band_id = band
             band_str = band
 
         # Get this band's suffix
@@ -385,13 +545,13 @@ class S3SlstrProduct(S3Product):
 
         # Get band filename and subdataset
         pp_name = subdataset if subdataset else band_str
-        if band_name in SLSTR_RAD_BANDS:
+        if band_id in SLSTR_RAD_BANDS:
             if not subdataset:
                 subdataset = self._replace(
                     self._radiance_subds, band=band, suffix=suffix
                 )
             filename = self._replace(self._radiance_file, band=band, suffix=suffix)
-        elif band_name in SLSTR_BT_BANDS:
+        elif band_id in SLSTR_BT_BANDS:
             if not subdataset:
                 subdataset = self._replace(self._bt_subds, band=band, suffix=suffix)
             filename = self._replace(self._bt_file, band=band, suffix=suffix)
@@ -414,7 +574,7 @@ class S3SlstrProduct(S3Product):
             )
 
             # Radiance pre process (BT bands are given in BT !)
-            if not kwargs.get("flags", False) and band_name in SLSTR_RAD_BANDS:
+            if not kwargs.get("flags", False) and band_id in SLSTR_RAD_BANDS:
                 # Adjust radiance if needed
                 # Get the user's radiance adjustment if existing
                 rad_adjust = kwargs.get(SLSTR_RAD_ADJUST, self._rad_adjust)
@@ -452,7 +612,7 @@ class S3SlstrProduct(S3Product):
 
         return path
 
-    def _get_suffix(self, band: Union[str, obn] = None, **kwargs) -> str:
+    def _get_suffix(self, band: Union[str, BandNames] = None, **kwargs) -> str:
         """
         Get the suffix according to the (given) stripe and view.
             - "an" and "ao" refer to the 500 m grid, stripe A, respectively for nadir view (n) and oblique view (o)
@@ -462,7 +622,7 @@ class S3SlstrProduct(S3Product):
             - "fn" and "fo" refer to the F1 channel 1 km grid
 
         Args:
-            band (Union[obn, str]): Band from which to get the stripe
+            band (Union[BandNames, str]): Band from which to get the stripe
             kwargs: Other arguments
 
         Returns:
@@ -473,8 +633,8 @@ class S3SlstrProduct(S3Product):
 
         if band is not None:
             # Get the stripe
-            if isinstance(band, obn):
-                band = self.band_names[band]
+            if isinstance(band, BandNames):
+                band = self.bands[band].id
 
             if band in SLSTR_I_BANDS:
                 stripe = SlstrStripe.I
@@ -527,7 +687,7 @@ class S3SlstrProduct(S3Product):
         band_arr.rio.write_crs(WGS84, inplace=True)
 
         return band_arr.rio.reproject(
-            dst_crs=self.crs,
+            dst_crs=self.crs(),
             resolution=resolution,
             gcps=self._gcps[suffix],
             nodata=self._mask_nodata if band_arr.dtype == np.uint8 else self.nodata,
@@ -578,7 +738,7 @@ class S3SlstrProduct(S3Product):
 
         return img_arr
 
-    # def _bt_2_rad(self, band_arr: xr.DataArray, band: obn = None) -> xr.DataArray:
+    # def _bt_2_rad(self, band_arr: xr.DataArray, band: BandNames = None) -> xr.DataArray:
     #     """
     #     Convert brightness temperature to radiance
     #
@@ -592,7 +752,7 @@ class S3SlstrProduct(S3Product):
     #
     #     Args:
     #         band_arr (xr.DataArray): Band array
-    #         band (obn): Optical Band
+    #         band (BandNames): Spectral Band
     #
     #     Returns:
     #         dict: Dictionary containing {band: path}
@@ -601,7 +761,7 @@ class S3SlstrProduct(S3Product):
     #     return band_arr
 
     def _rad_2_refl(
-        self, band_arr: xr.DataArray, band: obn, suffix: str
+        self, band_arr: xr.DataArray, band: BandNames, suffix: str
     ) -> xr.DataArray:
         """
         Convert radiance to reflectance
@@ -621,7 +781,7 @@ class S3SlstrProduct(S3Product):
 
         Args:
             band_arr (xr.DataArray): Band array
-            band (obn): Optical Band
+            band (BandNames): Spectral Band
             suffix (str): Band suffix
 
         Returns:
@@ -658,7 +818,7 @@ class S3SlstrProduct(S3Product):
     def _radiance_adjustment(
         self,
         band_arr: xr.DataArray,
-        band: Union[str, obn],
+        band: Union[str, BandNames],
         view: str,
         rad_adjust: SlstrRadAdjust = SlstrRadAdjust.S3_PN_SLSTR_L1_08,
     ) -> xr.DataArray:
@@ -688,7 +848,7 @@ class S3SlstrProduct(S3Product):
 
         Args:
             band_arr (xr.DataArray): Band array
-            band (obn): Optical Band
+            band (Union[str, BandNames]): Optical Band
             view (str): View (n or o for Nadir and Oblique)
             rad_adjust (SlstrRadAdjust): Radiance Adjustment
 
@@ -696,8 +856,8 @@ class S3SlstrProduct(S3Product):
             xr.DataArray: Adjusted band array
         """
         try:
-            band_name = self.band_names[band]
-            if band_name in SLSTR_RAD_BANDS:
+            band_id = self.bands[band].id
+            if band_id in SLSTR_RAD_BANDS:
                 # Allow the tuple and the enum
                 if isinstance(rad_adjust, SlstrRadAdjust):
                     rad_adjust_tuple = rad_adjust.value
@@ -705,7 +865,7 @@ class S3SlstrProduct(S3Product):
                     rad_adjust_tuple = rad_adjust
 
                 # Get the band coefficient and multiply the band
-                rad_coeff = getattr(rad_adjust_tuple, f"{band_name}_{view}")
+                rad_coeff = getattr(rad_adjust_tuple, f"{band_id}_{view}")
                 band_arr *= rad_coeff
         except KeyError:
             # Not a band (ie Quality Flags) or Brilliance temperature: no adjust needed
@@ -743,12 +903,12 @@ class S3SlstrProduct(S3Product):
 
         return sza_img
 
-    def _compute_e0(self, band: obn, suffix: str) -> np.ndarray:
+    def _compute_e0(self, band: BandNames, suffix: str) -> np.ndarray:
         """
         Compute the solar spectral flux in mW / (m^2 * sr * nm)
 
         Args:
-            band (obn): Optical Band
+            band (BandNames): Optical Band
             suffix (str): Suffix
 
         Returns:
@@ -766,20 +926,20 @@ class S3SlstrProduct(S3Product):
         return e0
 
     def _manage_invalid_pixels(
-        self, band_arr: XDS_TYPE, band: obn, **kwargs
-    ) -> XDS_TYPE:
+        self, band_arr: xr.DataArray, band: BandNames, **kwargs
+    ) -> xr.DataArray:
         """
         Manage invalid pixels (Nodata, saturated, defective...)
 
         ISP_absent pixel_absent not_decompressed no_signal saturation invalid_radiance no_parameters unfilled_pixel"
 
         Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
+            band_arr (xr.DataArray): Band array
+            band (BandNames): Band name as a SpectralBandNames
             kwargs: Other arguments used to load bands
 
         Returns:
-            XDS_TYPE: Cleaned band array
+            xr.DataArray: Cleaned band array
         """
         # Open quality flags
         # NOT OPTIMIZED, MAYBE CHECK INVALID PIXELS ON NOT GEOCODED DATA
@@ -986,10 +1146,14 @@ class S3SlstrProduct(S3Product):
         sun_az = self._read_nc(geom_file, saa_name)
         sun_ze = self._read_nc(geom_file, sza_name)
 
-        return sun_az.mean().data % 360, sun_ze.mean().data
+        return float(sun_az.mean().data) % 360, float(sun_ze.mean().data)
 
     def _get_clean_band_path(
-        self, band: obn, resolution: float = None, writable: bool = False, **kwargs
+        self,
+        band: BandNames,
+        resolution: float = None,
+        writable: bool = False,
+        **kwargs,
     ) -> Union[CloudPath, Path]:
         """
         Get clean band path.
@@ -997,7 +1161,7 @@ class S3SlstrProduct(S3Product):
         The clean band is the opened band where invalid pixels have been managed.
 
         Args:
-            band (OpticalBandNames): Wanted band
+            band (BandNames): Wanted band
             resolution (float): Band resolution in meters
             kwargs: Additional arguments
 
