@@ -27,19 +27,17 @@ from pathlib import Path
 from typing import Union
 
 import affine
-import geopandas as gpd
 import numpy as np
 import rasterio
+import xarray as xr
 from cloudpathlib import AnyPath, CloudPath
-from rasterio import rpc, transform, warp
+from rasterio import rpc, warp
 from rasterio.crs import CRS
 from rasterio.enums import Resampling
 from sertit import files, rasters, rasters_rio
-from sertit.rasters import XDS_TYPE
 from sertit.snap import MAX_CORES
-from shapely.geometry import box
 
-from eoreader import cached_property, utils
+from eoreader import utils
 from eoreader.bands.bands import BandNames
 from eoreader.env_vars import DEM_PATH
 from eoreader.exceptions import InvalidProductError
@@ -63,6 +61,7 @@ class VhrProduct(OpticalProduct):
         archive_path: Union[str, CloudPath, Path] = None,
         output_path: Union[str, CloudPath, Path] = None,
         remove_tmp: bool = False,
+        **kwargs,
     ) -> None:
         self.ortho_path = None
         """
@@ -73,12 +72,32 @@ class VhrProduct(OpticalProduct):
         self._proj_prod_type = []
 
         self.band_combi = None
+        """
+        Band combination, i.e. PAN, PMS, MS...
+        """
 
         # Order id (product name more or less)
         self._order_id = None
 
+        # Resolutions
+        self._pan_res = None
+        self._ms_res = None
+
+        self._job_id = None
+
         # Initialization from the super class
-        super().__init__(product_path, archive_path, output_path, remove_tmp)
+        super().__init__(product_path, archive_path, output_path, remove_tmp, **kwargs)
+
+    def _post_init(self, **kwargs) -> None:
+        """
+        Function used to post_init the products
+        (setting sensor type, band names and so on)
+        """
+        # Job ID
+        self._job_id = self._get_job_id()
+
+        # Post init done by the super class
+        super()._post_init(**kwargs)
 
     def get_default_band_path(self, **kwargs) -> Union[CloudPath, Path]:
         """
@@ -116,49 +135,6 @@ class VhrProduct(OpticalProduct):
         """
         raise NotImplementedError
 
-    @cached_property
-    def extent(self) -> gpd.GeoDataFrame:
-        """
-        Get UTM extent of the tile
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
-            >>> prod = Reader().open(path)
-            >>> prod.utm_extent()
-                                                        geometry
-            0  POLYGON ((309780.000 4390200.000, 309780.000 4...
-
-        Returns:
-            gpd.GeoDataFrame: Footprint in UTM
-        """
-        def_tr, def_w, def_h, def_crs = self.default_transform()
-        bounds = transform.array_bounds(def_h, def_w, def_tr)
-        return gpd.GeoDataFrame(geometry=[box(*bounds)], crs=def_crs).to_crs(self.crs)
-
-    @cached_property
-    def footprint(self) -> gpd.GeoDataFrame:
-        """
-        Get real footprint in UTM of the products (without nodata, in french == emprise utile)
-
-        .. code-block:: python
-
-            >>> from eoreader.reader import Reader
-            >>> path = r"IMG_PHR1B_PMS_001"
-            >>> prod = Reader().open(path)
-            >>> prod.footprint
-                                                         gml_id  ...                                           geometry
-            0  source_image_footprint-DS_PHR1A_20200511023124...  ...  POLYGON ((707025.261 9688613.833, 707043.276 9...
-            [1 rows x 3 columns]
-
-        Returns:
-            gpd.GeoDataFrame: Footprint as a GeoDataFrame
-        """
-        # Get footprint
-        # TODO: Optimize that
-        return rasters.get_footprint(self.get_default_band_path()).to_crs(self.crs)
-
     def _get_ortho_path(self, **kwargs) -> Union[CloudPath, Path]:
         """
         Get the orthorectified path of the bands.
@@ -215,9 +191,9 @@ class VhrProduct(OpticalProduct):
             >>> prod = Reader().open(path)
             >>> prod.get_band_paths([GREEN, RED])
             {
-                <OpticalBandNames.GREEN: 'GREEN'>:
+                <SpectralBandNames.GREEN: 'GREEN'>:
                 'IMG_PHR1A_PMS_001/DIM_PHR1A_PMS_202005110231585_ORT_5547047101.XML',
-                <OpticalBandNames.RED: 'RED'>:
+                <SpectralBandNames.RED: 'RED'>:
                 'IMG_PHR1A_PMS_001/DIM_PHR1A_PMS_202005110231585_ORT_5547047101.XML'
             }
 
@@ -243,7 +219,7 @@ class VhrProduct(OpticalProduct):
                 band_paths[band] = clean_band
             else:
                 # First look for reprojected bands
-                reproj_path = self._create_utm_band_path(
+                reproj_path = self._get_utm_band_path(
                     band=band.name, resolution=resolution
                 )
                 if not reproj_path.is_file():
@@ -311,7 +287,7 @@ class VhrProduct(OpticalProduct):
             src_arr,
             rpcs=rpcs,
             src_crs=self._get_raw_crs(),
-            dst_crs=self.crs,
+            dst_crs=self.crs(),
             resolution=self.resolution,
             src_nodata=0,
             dst_nodata=0,  # input data should be in integer
@@ -328,7 +304,7 @@ class VhrProduct(OpticalProduct):
         meta["driver"] = "GTiff"
         meta["compress"] = "lzw"
         meta["nodata"] = 0
-        meta["crs"] = self.crs
+        meta["crs"] = self.crs()
         meta["width"] = width
         meta["height"] = height
         meta["count"] = count
@@ -349,7 +325,7 @@ class VhrProduct(OpticalProduct):
         resolution: Union[tuple, list, float] = None,
         size: Union[list, tuple] = None,
         **kwargs,
-    ) -> XDS_TYPE:
+    ) -> xr.DataArray:
         """
         Read band from disk.
 
@@ -363,7 +339,7 @@ class VhrProduct(OpticalProduct):
             size (Union[tuple, list]): Size of the array (width, height). Not used if resolution is provided.
             kwargs: Other arguments used to load bands
         Returns:
-            XDS_TYPE: Band xarray
+            xr.DataArray: Band xarray
         """
         with rasterio.open(str(path)) as dst:
             dst_crs = dst.crs
@@ -373,14 +349,12 @@ class VhrProduct(OpticalProduct):
                 resolution = self._resolution_from_size(size)
 
             # Reproj path in case
-            reproj_path = self._create_utm_band_path(
-                band=band.name, resolution=resolution
-            )
+            reproj_path = self._get_utm_band_path(band=band.name, resolution=resolution)
 
             # Manage the case if we got a LAT LON product
             if not dst_crs.is_projected:
                 if not reproj_path.is_file():
-                    reproj_path = self._create_utm_band_path(
+                    reproj_path = self._get_utm_band_path(
                         band=band.name, resolution=resolution, writable=True
                     )
                     # Warp band if needed
@@ -392,7 +366,7 @@ class VhrProduct(OpticalProduct):
                     )
 
                 # Read band
-                band_xda = utils.read(
+                band_arr = utils.read(
                     reproj_path,
                     resolution=resolution,
                     size=size,
@@ -403,7 +377,7 @@ class VhrProduct(OpticalProduct):
             # Manage the case if we open a simple band (EOReader processed bands)
             elif dst.count == 1:
                 # Read band
-                band_xda = utils.read(
+                band_arr = utils.read(
                     path,
                     resolution=resolution,
                     size=size,
@@ -414,32 +388,20 @@ class VhrProduct(OpticalProduct):
             # Manage the case if we open a stack (native DIMAP bands)
             else:
                 # Read band
-                band_xda = utils.read(
+                band_arr = utils.read(
                     path,
                     resolution=resolution,
                     size=size,
                     resampling=Resampling.bilinear,
-                    indexes=[self.band_names[band]],
+                    indexes=[self.bands[band].id],
                     **kwargs,
                 )
 
-            # If nodata not set, set it here
-            if not band_xda.rio.encoded_nodata:
-                band_xda = rasters.set_nodata(band_xda, 0)
+        # Pop useless long name
+        if "long_name" in band_arr.attrs:
+            band_arr.attrs.pop("long_name")
 
-            # Compute the correct radiometry of the band
-            if dst.meta["dtype"] == "uint16":
-                band_xda /= 10000.0
-
-            # Pop useless long name
-            if "long_name" in band_xda.attrs:
-                band_xda.attrs.pop("long_name")
-
-            # To float32
-            if band_xda.dtype != np.float32:
-                band_xda = band_xda.astype(np.float32)
-
-        return band_xda
+        return band_arr
 
     def _load_bands(
         self,
@@ -476,38 +438,39 @@ class VhrProduct(OpticalProduct):
         return band_arrays
 
     def _manage_invalid_pixels(
-        self, band_arr: XDS_TYPE, band: BandNames, **kwargs
-    ) -> XDS_TYPE:
+        self, band_arr: xr.DataArray, band: BandNames, **kwargs
+    ) -> xr.DataArray:
         """
         Manage invalid pixels (Nodata, saturated, defective...)
-        See
-        `here <https://earth.esa.int/eogateway/documents/20142/37627/Planet-combined-imagery-product-specs-2020.pdf>`_
-        (unusable data mask) for more information.
 
         Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
+            band_arr (xr.DataArray): Band array
+            band (BandNames): Band name as an SpectralBandNames
             kwargs: Other arguments used to load bands
 
         Returns:
-            XDS_TYPE: Cleaned band array
+            xr.DataArray: Cleaned band array
         """
-        # Do nothing
-        return band_arr
+        return self._manage_nodata(band_arr, band, **kwargs)
 
-    def _manage_nodata(self, band_arr: XDS_TYPE, band: BandNames, **kwargs) -> XDS_TYPE:
+    def _manage_nodata(
+        self, band_arr: xr.DataArray, band: BandNames, **kwargs
+    ) -> xr.DataArray:
         """
         Manage only nodata pixels
 
         Args:
-            band_arr (XDS_TYPE): Band array
-            band (obn): Band name as an OpticalBandNames
+            band_arr (xr.DataArray): Band array
+            band (BandNames): Band name as an SpectralBandNames
             kwargs: Other arguments used to load bands
 
         Returns:
-            XDS_TYPE: Cleaned band array
+            xr.DataArray: Cleaned band array
         """
-        # Do nothing
+        # If nodata not set, set it here
+        if not band_arr.rio.encoded_nodata:
+            band_arr = rasters.set_nodata(band_arr, 0)
+
         return band_arr
 
     def _get_condensed_name(self) -> str:
@@ -517,7 +480,7 @@ class VhrProduct(OpticalProduct):
         Returns:
             str: Condensed name
         """
-        return f"{self.get_datetime()}_{self.platform.name}_{self.product_type.name}_{self.band_combi.name}"
+        return f"{self.get_datetime()}_{self.constellation.name}_{self.product_type.name}_{self.band_combi.name}_{self._job_id}"
 
     def _get_path(
         self, filename: str = "", extension: str = ""
@@ -553,7 +516,7 @@ class VhrProduct(OpticalProduct):
 
         return path
 
-    def _create_utm_band_path(
+    def _get_utm_band_path(
         self,
         band: str,
         resolution: Union[float, tuple, list] = None,
@@ -606,12 +569,12 @@ class VhrProduct(OpticalProduct):
 
         # Read band
         with rasterio.open(str(path)) as src:
-            band_nb = self.band_names[band]
+            band_id = self.bands[band].id
             meta = src.meta.copy()
 
             utm_tr, utm_w, utm_h = warp.calculate_default_transform(
                 src.crs,
-                self.crs,
+                self.crs(),
                 src.width,
                 src.height,
                 *src.bounds,
@@ -624,10 +587,10 @@ class VhrProduct(OpticalProduct):
             # If the CRS is not in UTM, reproject it
             out_arr = np.empty((1, utm_h, utm_w), dtype=meta["dtype"])
             warp.reproject(
-                source=src.read(band_nb),
+                source=src.read(band_id),
                 destination=out_arr,
                 src_crs=src.crs,
-                dst_crs=self.crs,
+                dst_crs=self.crs(),
                 src_transform=src.transform,
                 dst_transform=utm_tr,
                 src_nodata=0,
@@ -635,7 +598,7 @@ class VhrProduct(OpticalProduct):
                 num_threads=MAX_CORES,
             )
             meta["transform"] = utm_tr
-            meta["crs"] = self.crs
+            meta["crs"] = self.crs()
             meta["driver"] = "GTiff"
 
             rasters_rio.write(out_arr, meta, reproj_path)
@@ -681,13 +644,13 @@ class VhrProduct(OpticalProduct):
 
                 if not dst_crs.is_projected:
                     def_band = self.get_default_band()
-                    path = self._create_utm_band_path(
+                    path = self._get_utm_band_path(
                         band=def_band.name, resolution=resolution
                     )
 
                     # Warp band if needed
                     if not path.is_file():
-                        path = self._create_utm_band_path(
+                        path = self._get_utm_band_path(
                             band=def_band.name, resolution=resolution, writable=True
                         )
                         self._warp_band(
@@ -733,9 +696,34 @@ class VhrProduct(OpticalProduct):
     @abstractmethod
     def _get_tile_path(self) -> Union[CloudPath, Path]:
         """
-        Get the DIMAP filepath
+        Get the VHR tile path
 
         Returns:
-            Union[CloudPath, Path]: DIMAP filepath
+            Union[CloudPath, Path]: VHR filepath
         """
         raise NotImplementedError
+
+    @abstractmethod
+    def _get_job_id(self) -> Union[CloudPath, Path]:
+        """
+        Get VHR job ID
+
+        Returns:
+            Union[CloudPath, Path]: VHR product ID
+        """
+        raise NotImplementedError
+
+    def get_raw_band_paths(self, **kwargs) -> dict:
+        """
+        Return the raw band paths.
+
+        Args:
+            kwargs: Additional arguments
+
+        Returns:
+            dict: Dictionary containing the path of each queried band
+        """
+        raw_band_paths = {}
+        for band in self.get_existing_bands():
+            raw_band_paths[band] = self._get_tile_path()
+        return raw_band_paths
