@@ -20,28 +20,24 @@ More info `here <https://catalyst.earth/catalyst-system-files/help/references/gd
 """
 import difflib
 import logging
-import warnings
 from datetime import datetime
 from enum import unique
 from typing import Union
 
 import geopandas as gpd
-import rasterio
 from lxml import etree
 from sertit import vectors
 from sertit.misc import ListEnum
 from sertit.vectors import WGS84
 
-from eoreader import cache, cached_property
+from eoreader import cache
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.products import SarProduct, SarProductType
+from eoreader.products.product import OrbitDirection
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
-# Disable georef warnings here as the SAR products are not georeferenced
-warnings.filterwarnings("ignore", category=rasterio.errors.NotGeoreferencedWarning)
-
 
 @unique
 class RcmProductType(ListEnum):
@@ -117,21 +113,6 @@ class RcmSensorMode(ListEnum):
     """ Spotlight Mode [FSL] """
 
 
-@unique
-class RcmPolarization(ListEnum):
-    """
-    RADARSAT-Constellation polarization mode.
-    Take a look `here <https://catalyst.earth/catalyst-system-files/help/references/gdb_r/RADARSAT_Constellation.html>`_.
-    """
-
-    RH = "RH"
-    RV = "RV"
-    HH = "HH"
-    VV = "VV"
-    VH = "VH"
-    HV = "HV"
-
-
 class RcmProduct(SarProduct):
     """
     Class for RADARSAT-Constellation Products
@@ -139,9 +120,9 @@ class RcmProduct(SarProduct):
     You can use directly the .zip file
     """
 
-    def _set_resolution(self) -> float:
+    def _get_resolution(self) -> float:
         """
-        Set product default resolution (in meters)
+        Get product default resolution (in meters)
         See here
         <here](https://www.asc-csa.gc.ca/eng/satellites/radarsat/technical-features/radarsat-comparison.asp>`_
         for more information (Beam Modes)
@@ -165,7 +146,7 @@ class RcmProduct(SarProduct):
 
         return def_res
 
-    def _pre_init(self) -> None:
+    def _pre_init(self, **kwargs) -> None:
         """
         Function used to pre_init the products
         (setting needs_extraction and so on)
@@ -173,10 +154,13 @@ class RcmProduct(SarProduct):
         # SNAP cannot process zipped RCM
         self.needs_extraction = True
 
-        # Post init done by the super class
-        super()._pre_init()
+        # Its original filename is its name
+        self._use_filename = True
 
-    def _post_init(self) -> None:
+        # Post init done by the super class
+        super()._pre_init(**kwargs)
+
+    def _post_init(self, **kwargs) -> None:
         """
         Function used to post_init the products
         (setting product-type, band names and so on)
@@ -184,12 +168,12 @@ class RcmProduct(SarProduct):
         # Private attributes
         self._raw_band_regex = "*_{}.tif"
         self._band_folder = self.path / "imagery"
-        self._snap_path = ""
+        self.snap_filename = ""
 
         # Post init done by the super class
-        super()._post_init()
+        super()._post_init(**kwargs)
 
-    @cached_property
+    @cache
     def wgs84_extent(self) -> gpd.GeoDataFrame:
         """
         Get the WGS84 extent of the file before any reprojection.
@@ -223,6 +207,14 @@ class RcmProduct(SarProduct):
 
         return gpd.GeoDataFrame(geometry=extent_wgs84.geometry, crs=extent_wgs84.crs)
 
+    def _set_instrument(self) -> None:
+        """
+        Set instrument
+
+        RCM: https://earth.esa.int/web/eoportal/satellite-missions/r/rcm
+        """
+        self.instrument = "SAR C-band"
+
     def _set_product_type(self) -> None:
         """Set products type"""
         # Get MTD XML file
@@ -253,7 +245,7 @@ class RcmProduct(SarProduct):
             LOGGER.warning(
                 "Other products type than SGF has not been tested for %s data. "
                 "Use it at your own risks !",
-                self.platform.value,
+                self.constellation.value,
             )
 
     def _set_sensor_mode(self) -> None:
@@ -317,7 +309,7 @@ class RcmProduct(SarProduct):
 
         return date
 
-    def _get_name(self) -> str:
+    def _get_name_constellation_specific(self) -> str:
         """
         Set product real name from metadata
 
@@ -368,12 +360,12 @@ class RcmProduct(SarProduct):
 
     def _get_condensed_name(self) -> str:
         """
-        Get products condensed name ({acq_datetime}_RCM_{sensor_mode}_{product_type}).
+        Get products condensed name ({acq_datetime}_{constellation}_{polarization}_{sensor_mode}_{product_type}).
 
         Returns:
             str: Condensed RCM name
         """
-        # Get back the correct sensor name
+        # Get back the correct sensor mode name
         if self.sensor_mode == RcmSensorMode.THREE_M:
             mode_name = "3M"
         elif self.sensor_mode == RcmSensorMode.FIVE_M:
@@ -389,4 +381,51 @@ class RcmProduct(SarProduct):
         else:
             mode_name = self.sensor_mode.name
 
-        return f"{self.get_datetime()}_{self.platform.name}_{mode_name}_{self.product_type.value}"
+        pol_chan = [pol.value for pol in self.pol_channels]
+        return f"{self.get_datetime()}_{self.constellation.name}_{'_'.join(pol_chan)}_{mode_name}_{self.product_type.value}"
+
+    def get_quicklook_path(self) -> str:
+        """
+        Get quicklook path if existing.
+
+        Returns:
+            str: Quicklook path
+        """
+        quicklook_path = None
+        try:
+            quicklook_path = str(next(self.path.glob("preview/productOverview.png")))
+        except StopIteration:
+            LOGGER.warning(f"No quicklook found in {self.condensed_name}")
+
+        return quicklook_path
+
+    @cache
+    def get_orbit_direction(self) -> OrbitDirection:
+        """
+        Get cloud cover as given in the metadata
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_orbit_direction().value
+            "DESCENDING"
+
+        Returns:
+            OrbitDirection: Orbit direction (ASCENDING/DESCENDING)
+        """
+        # Get MTD XML file
+        root, nsmap = self.read_mtd()
+        namespace = nsmap[None]
+
+        # Get the orbit direction
+        try:
+            od = OrbitDirection.from_value(
+                root.findtext(f".//{namespace}passDirection").upper()
+            )
+
+        except TypeError:
+            raise InvalidProductError("passDirection not found in metadata!")
+
+        return od
