@@ -19,28 +19,24 @@ import logging
 import os
 import re
 import tempfile
-import warnings
 import zipfile
 from datetime import datetime
 from enum import unique
 from typing import Union
 
 import geopandas as gpd
-import rasterio
 from lxml import etree
-from sertit import vectors
+from sertit import files, vectors
 from sertit.misc import ListEnum
 
-from eoreader import cache, cached_property
+from eoreader import cache
 from eoreader.exceptions import InvalidProductError
 from eoreader.products import SarProduct, SarProductType
+from eoreader.products.product import OrbitDirection
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
-# Disable georef warnings here as the SAR products are not georeferenced
-warnings.filterwarnings("ignore", category=rasterio.errors.NotGeoreferencedWarning)
-
 
 @unique
 class S1ProductType(ListEnum):
@@ -94,9 +90,9 @@ class S1Product(SarProduct):
     You can use directly the .zip file
     """
 
-    def _set_resolution(self) -> float:
+    def _get_resolution(self) -> float:
         """
-        Set product default resolution (in meters)
+        Get product default resolution (in meters)
         See here
         <here](https://sentinel.esa.int/web/sentinel/user-guides/sentinel-1-sar/resolutions/level-1-ground-range-detected>`_
         for more information
@@ -113,7 +109,15 @@ class S1Product(SarProduct):
             raise InvalidProductError(f"Unknown sensor mode: {self.sensor_mode}")
         return def_res
 
-    def _pre_init(self) -> None:
+    def _set_instrument(self) -> None:
+        """
+        Set instrument
+
+        Sentinel-1: https://sentinels.copernicus.eu/web/sentinel/missions/sentinel-1/instrument-payload
+        """
+        self.instrument = "SAR C-band"
+
+    def _pre_init(self, **kwargs) -> None:
         """
         Function used to pre_init the products
         (setting needs_extraction and so on)
@@ -121,24 +125,27 @@ class S1Product(SarProduct):
         # Private attributes
         self._raw_band_regex = "*-{!l}-*.tiff"  # Just get the SLC-iw1 image for now
         self._band_folder = self.path.joinpath("measurement")
-        self._snap_path = ""
+        self.snap_filename = ""
+
+        # Its original filename is its name
+        self._use_filename = True
 
         # Zipped and SNAP can process its archive
         self.needs_extraction = False
 
         # Post init done by the super class
-        super()._pre_init()
+        super()._pre_init(**kwargs)
 
-    def _post_init(self) -> None:
+    def _post_init(self, **kwargs) -> None:
         """
         Function used to post_init the products
         (setting product-type, band names and so on)
         """
 
         # Post init done by the super class
-        super()._post_init()
+        super()._post_init(**kwargs)
 
-    @cached_property
+    @cache
     def wgs84_extent(self) -> gpd.GeoDataFrame:
         """
         Get the WGS84 extent of the file before any reprojection.
@@ -149,7 +156,7 @@ class S1Product(SarProduct):
             >>> from eoreader.reader import Reader
             >>> path = r"S1A_IW_GRDH_1SDV_20191215T060906_20191215T060931_030355_0378F7_3696.zip"
             >>> prod = Reader().open(path)
-            >>> prod.wgs84_extent
+            >>> prod.wgs84_extent()
                                    Name  ...                                           geometry
             0  Sentinel-1 Image Overlay  ...  POLYGON ((0.85336 42.24660, -2.32032 42.65493,...
             [1 rows x 12 columns]
@@ -236,7 +243,7 @@ class S1Product(SarProduct):
             )
         if not self.sensor_mode:
             raise InvalidProductError(
-                f"Invalid {self.platform.value} name: {self.name}"
+                f"Invalid {self.constellation.value} name: {self.name}"
             )
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
@@ -278,30 +285,41 @@ class S1Product(SarProduct):
 
         return date
 
-    def _get_name(self) -> str:
+    def _get_name_constellation_specific(self) -> str:
         """
         Set product real name from metadata
 
         Returns:
             str: True name of the product (from metadata)
         """
-        # The name is not in the classic metadata, but can be found in the manifest
         try:
-            mtd_from_path = "preview/product-preview.html"
-            mtd_archived = r"preview.*product-preview\.html"
+            if self.is_archived:
+                pdf_file = files.get_archived_path(self.path, r".*\.pdf", as_list=False)
+            else:
+                pdf_file = next(self.path.glob("*.pdf"))
+        except (FileNotFoundError, StopIteration):
+            # The name is not in the classic metadata, but can be found in the product-preview
+            try:
+                mtd_from_path = "preview/product-preview.html"
+                mtd_archived = r"preview.*product-preview\.html"
 
-            root = self._read_mtd_html(mtd_from_path, mtd_archived)
+                root = self._read_mtd_html(mtd_from_path, mtd_archived)
 
-            # Open identifier
-            name = root.findtext(".//head/title")
-            if not name:
-                raise InvalidProductError("title not found in metadata!")
+                # Open identifier
+                name = root.findtext(".//head/title")
+                if not name:
+                    raise InvalidProductError("title not found in metadata!")
 
-        except InvalidProductError:
-            LOGGER.warning(
-                "product-preview.html not found in the product, the name will be the filename"
-            )
-            name = self.filename
+                LOGGER.warning(
+                    "Product filename is not a valid Sentinel-1 name, and the retrieved name is missing the unique ID."
+                )
+
+            except InvalidProductError:
+                raise InvalidProductError(
+                    "product-preview.html not found in the product, the name will be the filename (which is not a valid Sentinel-1 name)"
+                )
+        else:
+            name = files.get_filename(pdf_file)
 
         return name
 
@@ -327,3 +345,51 @@ class S1Product(SarProduct):
         mtd_archived = r"annotation/(?!rfi)(?!cal)(?!noise).*\.xml"
 
         return self._read_mtd_xml(mtd_from_path, mtd_archived)
+
+    def get_quicklook_path(self) -> str:
+        """
+        Get quicklook path if existing.
+
+        Returns:
+            str: Quicklook path
+        """
+        quicklook_path = None
+        try:
+            if self.is_archived:
+                quicklook_path = files.get_archived_rio_path(
+                    self.path, file_regex=r".*preview.quick-look\.png"
+                )
+            else:
+                quicklook_path = next(self.path.glob("preview/quick-look.png"))
+        except (StopIteration, FileNotFoundError):
+            LOGGER.warning(f"No quicklook found in {self.condensed_name}")
+
+        return quicklook_path
+
+    @cache
+    def get_orbit_direction(self) -> OrbitDirection:
+        """
+        Get cloud cover as given in the metadata
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_orbit_direction().value
+            "DESCENDING"
+
+        Returns:
+            OrbitDirection: Orbit direction (ASCENDING/DESCENDING)
+        """
+        # Get MTD XML file
+        root, _ = self.read_mtd()
+
+        # Get the orbit direction
+        try:
+            od = OrbitDirection.from_value(root.findtext(".//pass").upper())
+
+        except TypeError:
+            raise InvalidProductError("pass not found in metadata!")
+
+        return od
