@@ -19,29 +19,28 @@ TerraSAR-X & TanDEM-X & PAZ products.
 More info `here <https://tandemx-science.dlr.de/pdfs/TX-GS-DD-3302_Basic-Products-Specification-Document_V1.9.pdf>`_.
 """
 import logging
-import warnings
 from datetime import datetime
 from enum import unique
+from pathlib import Path
 from typing import Union
 
 import geopandas as gpd
 import rasterio
+from cloudpathlib import CloudPath
 from lxml import etree
 from rasterio import crs
 from sertit import files, rasters, vectors
 from sertit.misc import ListEnum
 
-from eoreader import cache, cached_property
+from eoreader import cache
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.products import SarProduct, SarProductType
-from eoreader.reader import Platform
+from eoreader.products.product import OrbitDirection
+from eoreader.reader import Constellation
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
 
-# Disable georef warnings here as the SAR products are not georeferenced
-warnings.filterwarnings("ignore", category=rasterio.errors.NotGeoreferencedWarning)
-
 
 @unique
 class TsxProductType(ListEnum):
@@ -133,21 +132,66 @@ class TsxSatId(ListEnum):
     """
 
 
+@unique
+class TsxGeometricResolution(ListEnum):
+    """
+    TerraSAR-X & TanDEM-X & PAZ geometric resolution, either Radiometrically Enhanced Products or Spatially Enhanced Products.
+    This would infer on the resolution of the band, but Copernicus EMS doesn't handled this so we keep SSC resolution as is ESA Data Access Portfolio.
+
+    Take a look
+    `here <https://tandemx-science.dlr.de/pdfs/TX-GS-DD-3302_Basic-Products-Specification-Document_V1.9.pdf>`_
+    """
+
+    RE = "Radiometrically Enhanced Products "
+    """The radiometrically enhanced product is optimized with respect to radiometry."""
+
+    SE = "Spatially Enhanced Products "
+    """The spatially enhanced product is designed for the highest possible square ground resolution."""
+
+
 class TsxProduct(SarProduct):
     """Class for TerraSAR-X & TanDEM-X & PAZ Products"""
 
-    def _set_resolution(self) -> float:
+    class IceyeProduct(SarProduct):
         """
-        Set product default resolution (in meters)
+        Class for ICEYE Products
+        Take a look
+        `here <https://www.iceye.com/hubfs/Downloadables/ICEYE-Level-1-Product-Specs-2019.pdf>`_.
+        """
+
+        def __init__(
+            self,
+            product_path: Union[str, CloudPath, Path],
+            archive_path: Union[str, CloudPath, Path] = None,
+            output_path: Union[str, CloudPath, Path] = None,
+            remove_tmp: bool = False,
+            **kwargs,
+        ) -> None:
+            self._geometric_res = None
+
+            # Initialization from the super class
+            super().__init__(
+                product_path, archive_path, output_path, remove_tmp, **kwargs
+            )
+
+            # Geometric resolution
+            if self.product_type != TsxProductType.SSC:
+                self._geometric_res = getattr(
+                    TsxGeometricResolution, self.split_name[3]
+                )
+
+    def _get_resolution(self) -> float:
+        """
+        Get product default resolution (in meters)
         See here
         <here](https://tandemx-science.dlr.de/pdfs/TX-GS-DD-3302_Basic-Products-Specification-Document_V1.9.pdf>`_
         for more information (Beam Modes)
 
         .. WARNING::
-            For SSC data:
-                - We assume being in High Resolution (SE)
-                - Incidence angle: we consider the worst option, around 20 degrees
+            - We force Spatially Enhanced Resolution (SE) as we keep SSC resolutions (as per the ESA Data Access Portfolio)
         """
+        # TODO: Manage RE case ? Not handled by Copernicus EMS, so be careful...
+
         # Read metadata
         try:
             root, _ = self.read_mtd()
@@ -201,7 +245,16 @@ class TsxProduct(SarProduct):
 
         return def_res
 
-    def _pre_init(self) -> None:
+    def _set_instrument(self) -> None:
+        """
+        Set instrument
+
+        TSX+TDX: https://earth.esa.int/eogateway/missions/terrasar-x-and-tandem-x
+        PAZ: https://earth.esa.int/eogateway/missions/paz
+        """
+        self.instrument = "SAR X-band"
+
+    def _pre_init(self, **kwargs) -> None:
         """
         Function used to pre_init the products
         (setting needs_extraction and so on)
@@ -213,30 +266,33 @@ class TsxProduct(SarProduct):
         # SNAP cannot process its archive
         self.needs_extraction = True
 
+        # Its original filename is its name
+        self._use_filename = True
+
         # Post init done by the super class
-        super()._pre_init()
+        super()._pre_init(**kwargs)
 
-    def _get_platform(self) -> Platform:
-        """ Getter of the platform """
-        # TerraSAR-X & TanDEM-X products are all similar, we must check into the metadata to know the sensor
+    def _get_constellation(self) -> Constellation:
+        """ Getter of the constellation """
+        # TerraSAR-X & TanDEM-X products are all similar, we must check into the metadata to know the constellation
         root, _ = self.read_mtd()
-        sat_id = root.findtext(".//mission")
-        if not sat_id:
+        mission = root.findtext(".//mission")
+        if not mission:
             raise InvalidProductError("Cannot find mission in the metadata file")
-        sat_id = getattr(TsxSatId, sat_id.split("-")[0]).name
-        return getattr(Platform, sat_id)
+        constellation_id = getattr(TsxSatId, mission.split("-")[0]).name
+        return getattr(Constellation, constellation_id)
 
-    def _post_init(self) -> None:
+    def _post_init(self, **kwargs) -> None:
         """
         Function used to post_init the products
         (setting product-type, band names and so on)
         """
-        self._snap_path = f"{self.name}.xml"
+        self.snap_filename = f"{self.name}.xml"
 
         # Post init done by the super class
-        super()._post_init()
+        super()._post_init(**kwargs)
 
-    @cached_property
+    @cache
     def extent(self) -> gpd.GeoDataFrame:
         """
         Get UTM extent of the tile
@@ -252,14 +308,14 @@ class TsxProduct(SarProduct):
             [1 rows x 12 columns]
 
         Returns:
-            gpd.GeoDataFrame: Footprint in UTM
+            gpd.GeoDataFrame: Extent in UTM
         """
         if self.product_type == TsxProductType.EEC:
-            return rasters.get_extent(self.get_default_band_path()).to_crs(self.crs)
+            return rasters.get_extent(self.get_default_band_path()).to_crs(self.crs())
         else:
-            return super().extent
+            return super().extent()
 
-    @cached_property
+    @cache
     def crs(self) -> crs.CRS:
         """
         Get UTM projection
@@ -279,9 +335,9 @@ class TsxProduct(SarProduct):
             with rasterio.open(self.get_default_band_path()) as ds:
                 return ds.crs
         else:
-            return super().crs
+            return super().crs()
 
-    @cached_property
+    @cache
     def wgs84_extent(self) -> gpd.GeoDataFrame:
         """
         Get the WGS84 extent of the file before any reprojection.
@@ -292,7 +348,7 @@ class TsxProduct(SarProduct):
             >>> from eoreader.reader import Reader
             >>> path = r"TSX1_SAR__MGD_SE___SM_S_SRA_20160229T223018_20160229T223023"
             >>> prod = Reader().open(path)
-            >>> prod.wgs84_extent
+            >>> prod.wgs84_extent()
                                                         geometry
             0  POLYGON ((106.65491 -6.39693, 106.96233 -6.396...
 
@@ -340,8 +396,10 @@ class TsxProduct(SarProduct):
             LOGGER.warning(
                 "GEC (Geocoded Ellipsoid Corrected) products type has never been tested for %s data. "
                 "Use it at your own risks !",
-                self.platform.value,
+                self.constellation.value,
             )
+        elif self.product_type == TsxProductType.EEC:
+            self.is_ortho = True
 
     def _set_sensor_mode(self) -> None:
         """
@@ -400,7 +458,7 @@ class TsxProduct(SarProduct):
 
         return date
 
-    def _get_name(self) -> str:
+    def _get_name_constellation_specific(self) -> str:
         """
         Set product real name from metadata
 
@@ -446,3 +504,46 @@ class TsxProduct(SarProduct):
             mtd_from_path = "SAR*xml"
 
             return self._read_mtd_xml(mtd_from_path)
+
+    def get_quicklook_path(self) -> str:
+        """
+        Get quicklook path if existing.
+
+        Returns:
+            str: Quicklook path
+        """
+        quicklook_path = None
+        try:
+            quicklook_path = str(next(self.path.glob("PREVIEW/BROWSE.tif")))
+        except StopIteration:
+            LOGGER.warning(f"No quicklook found in {self.condensed_name}")
+
+        return quicklook_path
+
+    @cache
+    def get_orbit_direction(self) -> OrbitDirection:
+        """
+        Get cloud cover as given in the metadata
+
+        .. code-block:: python
+
+            >>> from eoreader.reader import Reader
+            >>> path = r"S2A_MSIL1C_20200824T110631_N0209_R137_T30TTK_20200824T150432.SAFE.zip"
+            >>> prod = Reader().open(path)
+            >>> prod.get_orbit_direction().value
+            "DESCENDING"
+
+        Returns:
+            OrbitDirection: Orbit direction (ASCENDING/DESCENDING)
+        """
+        # Get MTD XML file
+        root, _ = self.read_mtd()
+
+        # Get the orbit direction
+        try:
+            od = OrbitDirection.from_value(root.findtext(".//orbitDirection"))
+
+        except TypeError:
+            raise InvalidProductError("orbitDirection not found in metadata!")
+
+        return od
